# Generated by ariadne-codegen

from .add_contents_to_collections import (
    AddContentsToCollections,
    AddContentsToCollectionsAddContentsToCollections,
    AddContentsToCollectionsAddContentsToCollectionsContents,
)
from .async_base_client import AsyncBaseClient
from .base_model import BaseModel, Upload
from .clear_conversation import ClearConversation, ClearConversationClearConversation
from .client import Client
from .close_conversation import CloseConversation, CloseConversationCloseConversation
from .count_alerts import CountAlerts, CountAlertsCountAlerts
from .count_categories import CountCategories, CountCategoriesCountCategories
from .count_collections import CountCollections, CountCollectionsCountCollections
from .count_contents import CountContents, CountContentsCountContents
from .count_conversations import (
    CountConversations,
    CountConversationsCountConversations,
)
from .count_events import CountEvents, CountEventsCountEvents
from .count_feeds import CountFeeds, CountFeedsCountFeeds
from .count_labels import CountLabels, CountLabelsCountLabels
from .count_medical_conditions import (
    CountMedicalConditions,
    CountMedicalConditionsCountMedicalConditions,
)
from .count_medical_contraindications import (
    CountMedicalContraindications,
    CountMedicalContraindicationsCountMedicalContraindications,
)
from .count_medical_devices import (
    CountMedicalDevices,
    CountMedicalDevicesCountMedicalDevices,
)
from .count_medical_drug_classes import (
    CountMedicalDrugClasses,
    CountMedicalDrugClassesCountMedicalDrugClasses,
)
from .count_medical_drugs import CountMedicalDrugs, CountMedicalDrugsCountMedicalDrugs
from .count_medical_guidelines import (
    CountMedicalGuidelines,
    CountMedicalGuidelinesCountMedicalGuidelines,
)
from .count_medical_indications import (
    CountMedicalIndications,
    CountMedicalIndicationsCountMedicalIndications,
)
from .count_medical_procedures import (
    CountMedicalProcedures,
    CountMedicalProceduresCountMedicalProcedures,
)
from .count_medical_studies import (
    CountMedicalStudies,
    CountMedicalStudiesCountMedicalStudies,
)
from .count_medical_tests import CountMedicalTests, CountMedicalTestsCountMedicalTests
from .count_medical_therapies import (
    CountMedicalTherapies,
    CountMedicalTherapiesCountMedicalTherapies,
)
from .count_organizations import (
    CountOrganizations,
    CountOrganizationsCountOrganizations,
)
from .count_persons import CountPersons, CountPersonsCountPersons
from .count_places import CountPlaces, CountPlacesCountPlaces
from .count_products import CountProducts, CountProductsCountProducts
from .count_repos import CountRepos, CountReposCountRepos
from .count_softwares import CountSoftwares, CountSoftwaresCountSoftwares
from .count_specifications import (
    CountSpecifications,
    CountSpecificationsCountSpecifications,
)
from .count_workflows import CountWorkflows, CountWorkflowsCountWorkflows
from .create_alert import CreateAlert, CreateAlertCreateAlert
from .create_category import CreateCategory, CreateCategoryCreateCategory
from .create_collection import CreateCollection, CreateCollectionCreateCollection
from .create_conversation import (
    CreateConversation,
    CreateConversationCreateConversation,
)
from .create_event import CreateEvent, CreateEventCreateEvent
from .create_feed import CreateFeed, CreateFeedCreateFeed
from .create_label import CreateLabel, CreateLabelCreateLabel
from .create_medical_condition import (
    CreateMedicalCondition,
    CreateMedicalConditionCreateMedicalCondition,
)
from .create_medical_contraindication import (
    CreateMedicalContraindication,
    CreateMedicalContraindicationCreateMedicalContraindication,
)
from .create_medical_device import (
    CreateMedicalDevice,
    CreateMedicalDeviceCreateMedicalDevice,
)
from .create_medical_drug import CreateMedicalDrug, CreateMedicalDrugCreateMedicalDrug
from .create_medical_drug_class import (
    CreateMedicalDrugClass,
    CreateMedicalDrugClassCreateMedicalDrugClass,
)
from .create_medical_guideline import (
    CreateMedicalGuideline,
    CreateMedicalGuidelineCreateMedicalGuideline,
)
from .create_medical_indication import (
    CreateMedicalIndication,
    CreateMedicalIndicationCreateMedicalIndication,
)
from .create_medical_procedure import (
    CreateMedicalProcedure,
    CreateMedicalProcedureCreateMedicalProcedure,
)
from .create_medical_study import (
    CreateMedicalStudy,
    CreateMedicalStudyCreateMedicalStudy,
)
from .create_medical_test import CreateMedicalTest, CreateMedicalTestCreateMedicalTest
from .create_medical_therapy import (
    CreateMedicalTherapy,
    CreateMedicalTherapyCreateMedicalTherapy,
)
from .create_observation import CreateObservation, CreateObservationCreateObservation
from .create_organization import (
    CreateOrganization,
    CreateOrganizationCreateOrganization,
)
from .create_person import CreatePerson, CreatePersonCreatePerson
from .create_place import CreatePlace, CreatePlaceCreatePlace
from .create_product import CreateProduct, CreateProductCreateProduct
from .create_repo import CreateRepo, CreateRepoCreateRepo
from .create_software import CreateSoftware, CreateSoftwareCreateSoftware
from .create_specification import (
    CreateSpecification,
    CreateSpecificationCreateSpecification,
)
from .create_workflow import (
    CreateWorkflow,
    CreateWorkflowCreateWorkflow,
    CreateWorkflowCreateWorkflowActions,
    CreateWorkflowCreateWorkflowActionsConnector,
    CreateWorkflowCreateWorkflowActionsConnectorSlack,
    CreateWorkflowCreateWorkflowEnrichment,
    CreateWorkflowCreateWorkflowEnrichmentJobs,
    CreateWorkflowCreateWorkflowEnrichmentJobsConnector,
    CreateWorkflowCreateWorkflowEnrichmentJobsConnectorFhir,
    CreateWorkflowCreateWorkflowEnrichmentLink,
    CreateWorkflowCreateWorkflowExtraction,
    CreateWorkflowCreateWorkflowExtractionJobs,
    CreateWorkflowCreateWorkflowExtractionJobsConnector,
    CreateWorkflowCreateWorkflowExtractionJobsConnectorAzureImage,
    CreateWorkflowCreateWorkflowExtractionJobsConnectorAzureText,
    CreateWorkflowCreateWorkflowExtractionJobsConnectorModelImage,
    CreateWorkflowCreateWorkflowExtractionJobsConnectorModelImageSpecification,
    CreateWorkflowCreateWorkflowExtractionJobsConnectorModelText,
    CreateWorkflowCreateWorkflowExtractionJobsConnectorModelTextSpecification,
    CreateWorkflowCreateWorkflowExtractionJobsConnectorOpenAiImage,
    CreateWorkflowCreateWorkflowIndexing,
    CreateWorkflowCreateWorkflowIndexingJobs,
    CreateWorkflowCreateWorkflowIndexingJobsConnector,
    CreateWorkflowCreateWorkflowIngestion,
    CreateWorkflowCreateWorkflowIngestionCollections,
    CreateWorkflowCreateWorkflowIngestionIf,
    CreateWorkflowCreateWorkflowPreparation,
    CreateWorkflowCreateWorkflowPreparationJobs,
    CreateWorkflowCreateWorkflowPreparationJobsConnector,
    CreateWorkflowCreateWorkflowPreparationJobsConnectorAzureDocument,
    CreateWorkflowCreateWorkflowPreparationJobsConnectorDeepgram,
    CreateWorkflowCreateWorkflowPreparationJobsConnectorDocument,
    CreateWorkflowCreateWorkflowPreparationJobsConnectorEmail,
    CreateWorkflowCreateWorkflowPreparationJobsConnectorModelDocument,
    CreateWorkflowCreateWorkflowPreparationJobsConnectorModelDocumentSpecification,
    CreateWorkflowCreateWorkflowPreparationSummarizations,
    CreateWorkflowCreateWorkflowPreparationSummarizationsSpecification,
    CreateWorkflowCreateWorkflowStorage,
    CreateWorkflowCreateWorkflowStorageEmbeddings,
)
from .delete_alert import DeleteAlert, DeleteAlertDeleteAlert
from .delete_alerts import DeleteAlerts, DeleteAlertsDeleteAlerts
from .delete_all_alerts import DeleteAllAlerts, DeleteAllAlertsDeleteAllAlerts
from .delete_all_categories import (
    DeleteAllCategories,
    DeleteAllCategoriesDeleteAllCategories,
)
from .delete_all_collections import (
    DeleteAllCollections,
    DeleteAllCollectionsDeleteAllCollections,
)
from .delete_all_contents import DeleteAllContents, DeleteAllContentsDeleteAllContents
from .delete_all_conversations import (
    DeleteAllConversations,
    DeleteAllConversationsDeleteAllConversations,
)
from .delete_all_events import DeleteAllEvents, DeleteAllEventsDeleteAllEvents
from .delete_all_feeds import DeleteAllFeeds, DeleteAllFeedsDeleteAllFeeds
from .delete_all_labels import DeleteAllLabels, DeleteAllLabelsDeleteAllLabels
from .delete_all_medical_conditions import (
    DeleteAllMedicalConditions,
    DeleteAllMedicalConditionsDeleteAllMedicalConditions,
)
from .delete_all_medical_contraindications import (
    DeleteAllMedicalContraindications,
    DeleteAllMedicalContraindicationsDeleteAllMedicalContraindications,
)
from .delete_all_medical_devices import (
    DeleteAllMedicalDevices,
    DeleteAllMedicalDevicesDeleteAllMedicalDevices,
)
from .delete_all_medical_drug_classes import (
    DeleteAllMedicalDrugClasses,
    DeleteAllMedicalDrugClassesDeleteAllMedicalDrugClasses,
)
from .delete_all_medical_drugs import (
    DeleteAllMedicalDrugs,
    DeleteAllMedicalDrugsDeleteAllMedicalDrugs,
)
from .delete_all_medical_guidelines import (
    DeleteAllMedicalGuidelines,
    DeleteAllMedicalGuidelinesDeleteAllMedicalGuidelines,
)
from .delete_all_medical_indications import (
    DeleteAllMedicalIndications,
    DeleteAllMedicalIndicationsDeleteAllMedicalIndications,
)
from .delete_all_medical_procedures import (
    DeleteAllMedicalProcedures,
    DeleteAllMedicalProceduresDeleteAllMedicalProcedures,
)
from .delete_all_medical_studies import (
    DeleteAllMedicalStudies,
    DeleteAllMedicalStudiesDeleteAllMedicalStudies,
)
from .delete_all_medical_tests import (
    DeleteAllMedicalTests,
    DeleteAllMedicalTestsDeleteAllMedicalTests,
)
from .delete_all_medical_therapies import (
    DeleteAllMedicalTherapies,
    DeleteAllMedicalTherapiesDeleteAllMedicalTherapies,
)
from .delete_all_organizations import (
    DeleteAllOrganizations,
    DeleteAllOrganizationsDeleteAllOrganizations,
)
from .delete_all_persons import DeleteAllPersons, DeleteAllPersonsDeleteAllPersons
from .delete_all_places import DeleteAllPlaces, DeleteAllPlacesDeleteAllPlaces
from .delete_all_products import DeleteAllProducts, DeleteAllProductsDeleteAllProducts
from .delete_all_repos import DeleteAllRepos, DeleteAllReposDeleteAllRepos
from .delete_all_softwares import (
    DeleteAllSoftwares,
    DeleteAllSoftwaresDeleteAllSoftwares,
)
from .delete_all_specifications import (
    DeleteAllSpecifications,
    DeleteAllSpecificationsDeleteAllSpecifications,
)
from .delete_all_workflows import (
    DeleteAllWorkflows,
    DeleteAllWorkflowsDeleteAllWorkflows,
)
from .delete_categories import DeleteCategories, DeleteCategoriesDeleteCategories
from .delete_category import DeleteCategory, DeleteCategoryDeleteCategory
from .delete_collection import DeleteCollection, DeleteCollectionDeleteCollection
from .delete_collections import DeleteCollections, DeleteCollectionsDeleteCollections
from .delete_content import DeleteContent, DeleteContentDeleteContent
from .delete_contents import DeleteContents, DeleteContentsDeleteContents
from .delete_conversation import (
    DeleteConversation,
    DeleteConversationDeleteConversation,
)
from .delete_conversations import (
    DeleteConversations,
    DeleteConversationsDeleteConversations,
)
from .delete_event import DeleteEvent, DeleteEventDeleteEvent
from .delete_events import DeleteEvents, DeleteEventsDeleteEvents
from .delete_feed import DeleteFeed, DeleteFeedDeleteFeed
from .delete_feeds import DeleteFeeds, DeleteFeedsDeleteFeeds
from .delete_label import DeleteLabel, DeleteLabelDeleteLabel
from .delete_labels import DeleteLabels, DeleteLabelsDeleteLabels
from .delete_medical_condition import (
    DeleteMedicalCondition,
    DeleteMedicalConditionDeleteMedicalCondition,
)
from .delete_medical_conditions import (
    DeleteMedicalConditions,
    DeleteMedicalConditionsDeleteMedicalConditions,
)
from .delete_medical_contraindication import (
    DeleteMedicalContraindication,
    DeleteMedicalContraindicationDeleteMedicalContraindication,
)
from .delete_medical_contraindications import (
    DeleteMedicalContraindications,
    DeleteMedicalContraindicationsDeleteMedicalContraindications,
)
from .delete_medical_device import (
    DeleteMedicalDevice,
    DeleteMedicalDeviceDeleteMedicalDevice,
)
from .delete_medical_devices import (
    DeleteMedicalDevices,
    DeleteMedicalDevicesDeleteMedicalDevices,
)
from .delete_medical_drug import DeleteMedicalDrug, DeleteMedicalDrugDeleteMedicalDrug
from .delete_medical_drug_class import (
    DeleteMedicalDrugClass,
    DeleteMedicalDrugClassDeleteMedicalDrugClass,
)
from .delete_medical_drug_classes import (
    DeleteMedicalDrugClasses,
    DeleteMedicalDrugClassesDeleteMedicalDrugClasses,
)
from .delete_medical_drugs import (
    DeleteMedicalDrugs,
    DeleteMedicalDrugsDeleteMedicalDrugs,
)
from .delete_medical_guideline import (
    DeleteMedicalGuideline,
    DeleteMedicalGuidelineDeleteMedicalGuideline,
)
from .delete_medical_guidelines import (
    DeleteMedicalGuidelines,
    DeleteMedicalGuidelinesDeleteMedicalGuidelines,
)
from .delete_medical_indication import (
    DeleteMedicalIndication,
    DeleteMedicalIndicationDeleteMedicalIndication,
)
from .delete_medical_indications import (
    DeleteMedicalIndications,
    DeleteMedicalIndicationsDeleteMedicalIndications,
)
from .delete_medical_procedure import (
    DeleteMedicalProcedure,
    DeleteMedicalProcedureDeleteMedicalProcedure,
)
from .delete_medical_procedures import (
    DeleteMedicalProcedures,
    DeleteMedicalProceduresDeleteMedicalProcedures,
)
from .delete_medical_studies import (
    DeleteMedicalStudies,
    DeleteMedicalStudiesDeleteMedicalStudies,
)
from .delete_medical_study import (
    DeleteMedicalStudy,
    DeleteMedicalStudyDeleteMedicalStudy,
)
from .delete_medical_test import DeleteMedicalTest, DeleteMedicalTestDeleteMedicalTest
from .delete_medical_tests import (
    DeleteMedicalTests,
    DeleteMedicalTestsDeleteMedicalTests,
)
from .delete_medical_therapies import (
    DeleteMedicalTherapies,
    DeleteMedicalTherapiesDeleteMedicalTherapies,
)
from .delete_medical_therapy import (
    DeleteMedicalTherapy,
    DeleteMedicalTherapyDeleteMedicalTherapy,
)
from .delete_observation import DeleteObservation, DeleteObservationDeleteObservation
from .delete_organization import (
    DeleteOrganization,
    DeleteOrganizationDeleteOrganization,
)
from .delete_organizations import (
    DeleteOrganizations,
    DeleteOrganizationsDeleteOrganizations,
)
from .delete_person import DeletePerson, DeletePersonDeletePerson
from .delete_persons import DeletePersons, DeletePersonsDeletePersons
from .delete_place import DeletePlace, DeletePlaceDeletePlace
from .delete_places import DeletePlaces, DeletePlacesDeletePlaces
from .delete_product import DeleteProduct, DeleteProductDeleteProduct
from .delete_products import DeleteProducts, DeleteProductsDeleteProducts
from .delete_repo import DeleteRepo, DeleteRepoDeleteRepo
from .delete_repos import DeleteRepos, DeleteReposDeleteRepos
from .delete_software import DeleteSoftware, DeleteSoftwareDeleteSoftware
from .delete_softwares import DeleteSoftwares, DeleteSoftwaresDeleteSoftwares
from .delete_specification import (
    DeleteSpecification,
    DeleteSpecificationDeleteSpecification,
)
from .delete_specifications import (
    DeleteSpecifications,
    DeleteSpecificationsDeleteSpecifications,
)
from .delete_workflow import DeleteWorkflow, DeleteWorkflowDeleteWorkflow
from .delete_workflows import DeleteWorkflows, DeleteWorkflowsDeleteWorkflows
from .disable_alert import DisableAlert, DisableAlertDisableAlert
from .disable_feed import DisableFeed, DisableFeedDisableFeed
from .enable_alert import EnableAlert, EnableAlertEnableAlert
from .enable_feed import EnableFeed, EnableFeedEnableFeed
from .enums import (
    AlertTypes,
    AnthropicModels,
    ApplyPolicy,
    AzureDocumentIntelligenceModels,
    AzureDocumentIntelligenceVersions,
    AzureOpenAIModels,
    BillableMetrics,
    CategoryFacetTypes,
    CohereModels,
    CollectionTypes,
    ContentFacetTypes,
    ContentIndexingServiceTypes,
    ContentPublishingFormats,
    ContentPublishingServiceTypes,
    ContentTypes,
    ConversationRoleTypes,
    ConversationSearchTypes,
    ConversationStrategyTypes,
    ConversationTypes,
    DeepgramModels,
    DeepseekModels,
    DeviceTypes,
    ElevenLabsModels,
    EmailListingTypes,
    EntityEnrichmentServiceTypes,
    EntityExtractionServiceTypes,
    EntityState,
    EntityTypes,
    EnvironmentTypes,
    EventFacetTypes,
    FacetValueTypes,
    FeedConnectorTypes,
    FeedListingTypes,
    FeedServiceTypes,
    FeedTypes,
    FilePreparationServiceTypes,
    FileTypes,
    GraphStrategyTypes,
    GroqModels,
    H3ResolutionTypes,
    ImageProjectionTypes,
    IntegrationServiceTypes,
    LabelFacetTypes,
    LinkTypes,
    MailImportance,
    MailPriority,
    MailSensitivity,
    MedicalConditionFacetTypes,
    MedicalContraindicationFacetTypes,
    MedicalDeviceFacetTypes,
    MedicalDrugClassFacetTypes,
    MedicalDrugFacetTypes,
    MedicalGuidelineFacetTypes,
    MedicalIndicationFacetTypes,
    MedicalProcedureFacetTypes,
    MedicalStudyFacetTypes,
    MedicalTestFacetTypes,
    MedicalTherapyFacetTypes,
    MetadataTypes,
    MistralModels,
    ModelServiceTypes,
    NotionTypes,
    ObservableTypes,
    OccurrenceTypes,
    OpenAIModels,
    OpenAIVisionDetailLevels,
    OperationTypes,
    OrderByTypes,
    OrderDirectionTypes,
    OrganizationFacetTypes,
    OrientationTypes,
    PersonFacetTypes,
    PlaceFacetTypes,
    PolicyTimeTypes,
    ProductFacetTypes,
    PromptStrategyTypes,
    RenditionTypes,
    ReplicateModels,
    RepoFacetTypes,
    RerankingModelServiceTypes,
    ResourceConnectorTypes,
    RetrievalStrategyTypes,
    RevisionStrategyTypes,
    SearchQueryTypes,
    SearchServiceTypes,
    SearchTypes,
    SharePointAuthenticationTypes,
    SiteTypes,
    SoftwareFacetTypes,
    SpecificationTypes,
    SummarizationTypes,
    TextRoles,
    TextTypes,
    TimedPolicyRecurrenceTypes,
    TimeIntervalTypes,
    UnitTypes,
    YouTubeTypes,
)
from .exceptions import (
    GraphQLClientError,
    GraphQLClientGraphQLError,
    GraphQLClientGraphQLMultiError,
    GraphQLClientHttpError,
    GraphQLClientInvalidResponseError,
)
from .extract_contents import (
    ExtractContents,
    ExtractContentsExtractContents,
    ExtractContentsExtractContentsContent,
    ExtractContentsExtractContentsSpecification,
)
from .get_alert import (
    GetAlert,
    GetAlertAlert,
    GetAlertAlertFilter,
    GetAlertAlertFilterAnd,
    GetAlertAlertFilterAndCollections,
    GetAlertAlertFilterAndFeeds,
    GetAlertAlertFilterAndObservations,
    GetAlertAlertFilterAndObservationsObservable,
    GetAlertAlertFilterAndWorkflows,
    GetAlertAlertFilterCollections,
    GetAlertAlertFilterContents,
    GetAlertAlertFilterCreationDateRange,
    GetAlertAlertFilterDateRange,
    GetAlertAlertFilterFeeds,
    GetAlertAlertFilterObservations,
    GetAlertAlertFilterObservationsObservable,
    GetAlertAlertFilterOr,
    GetAlertAlertFilterOrCollections,
    GetAlertAlertFilterOrFeeds,
    GetAlertAlertFilterOrObservations,
    GetAlertAlertFilterOrObservationsObservable,
    GetAlertAlertFilterOrWorkflows,
    GetAlertAlertFilterWorkflows,
    GetAlertAlertIntegration,
    GetAlertAlertIntegrationSlack,
    GetAlertAlertOwner,
    GetAlertAlertPublishing,
    GetAlertAlertPublishingElevenLabs,
    GetAlertAlertPublishSpecification,
    GetAlertAlertSummarySpecification,
)
from .get_category import GetCategory, GetCategoryCategory
from .get_collection import (
    GetCollection,
    GetCollectionCollection,
    GetCollectionCollectionContents,
    GetCollectionCollectionOwner,
)
from .get_content import (
    GetContent,
    GetContentContent,
    GetContentContentAddress,
    GetContentContentAudio,
    GetContentContentChildren,
    GetContentContentCollections,
    GetContentContentDocument,
    GetContentContentEmail,
    GetContentContentEmailBcc,
    GetContentContentEmailCc,
    GetContentContentEmailFrom,
    GetContentContentEmailTo,
    GetContentContentFeed,
    GetContentContentImage,
    GetContentContentIssue,
    GetContentContentLanguage,
    GetContentContentLinks,
    GetContentContentLocation,
    GetContentContentObservations,
    GetContentContentObservationsObservable,
    GetContentContentObservationsOccurrences,
    GetContentContentObservationsOccurrencesBoundingBox,
    GetContentContentObservationsRelated,
    GetContentContentOwner,
    GetContentContentPackage,
    GetContentContentPages,
    GetContentContentPagesChunks,
    GetContentContentParent,
    GetContentContentSegments,
    GetContentContentVideo,
    GetContentContentWorkflow,
)
from .get_conversation import (
    GetConversation,
    GetConversationConversation,
    GetConversationConversationAugmentedFilter,
    GetConversationConversationAugmentedFilterAnd,
    GetConversationConversationAugmentedFilterAndCollections,
    GetConversationConversationAugmentedFilterAndFeeds,
    GetConversationConversationAugmentedFilterAndObservations,
    GetConversationConversationAugmentedFilterAndObservationsObservable,
    GetConversationConversationAugmentedFilterAndWorkflows,
    GetConversationConversationAugmentedFilterCollections,
    GetConversationConversationAugmentedFilterContents,
    GetConversationConversationAugmentedFilterCreationDateRange,
    GetConversationConversationAugmentedFilterDateRange,
    GetConversationConversationAugmentedFilterFeeds,
    GetConversationConversationAugmentedFilterObservations,
    GetConversationConversationAugmentedFilterObservationsObservable,
    GetConversationConversationAugmentedFilterOr,
    GetConversationConversationAugmentedFilterOrCollections,
    GetConversationConversationAugmentedFilterOrFeeds,
    GetConversationConversationAugmentedFilterOrObservations,
    GetConversationConversationAugmentedFilterOrObservationsObservable,
    GetConversationConversationAugmentedFilterOrWorkflows,
    GetConversationConversationAugmentedFilterWorkflows,
    GetConversationConversationFilter,
    GetConversationConversationFilterAnd,
    GetConversationConversationFilterAndCollections,
    GetConversationConversationFilterAndFeeds,
    GetConversationConversationFilterAndObservations,
    GetConversationConversationFilterAndObservationsObservable,
    GetConversationConversationFilterAndWorkflows,
    GetConversationConversationFilterCollections,
    GetConversationConversationFilterContents,
    GetConversationConversationFilterCreationDateRange,
    GetConversationConversationFilterDateRange,
    GetConversationConversationFilterFeeds,
    GetConversationConversationFilterObservations,
    GetConversationConversationFilterObservationsObservable,
    GetConversationConversationFilterOr,
    GetConversationConversationFilterOrCollections,
    GetConversationConversationFilterOrFeeds,
    GetConversationConversationFilterOrObservations,
    GetConversationConversationFilterOrObservationsObservable,
    GetConversationConversationFilterOrWorkflows,
    GetConversationConversationFilterWorkflows,
    GetConversationConversationMessages,
    GetConversationConversationMessagesCitations,
    GetConversationConversationMessagesCitationsContent,
    GetConversationConversationMessagesCitationsContentAudio,
    GetConversationConversationMessagesCitationsContentDocument,
    GetConversationConversationMessagesCitationsContentImage,
    GetConversationConversationMessagesCitationsContentVideo,
    GetConversationConversationOwner,
    GetConversationConversationSpecification,
)
from .get_event import GetEvent, GetEventEvent, GetEventEventAddress
from .get_feed import (
    GetFeed,
    GetFeedFeed,
    GetFeedFeedDiscord,
    GetFeedFeedEmail,
    GetFeedFeedEmailGoogle,
    GetFeedFeedEmailMicrosoft,
    GetFeedFeedIssue,
    GetFeedFeedIssueGithub,
    GetFeedFeedIssueJira,
    GetFeedFeedIssueLinear,
    GetFeedFeedNotion,
    GetFeedFeedOwner,
    GetFeedFeedReddit,
    GetFeedFeedRss,
    GetFeedFeedSchedulePolicy,
    GetFeedFeedSearch,
    GetFeedFeedSite,
    GetFeedFeedSiteAzureBlob,
    GetFeedFeedSiteAzureFile,
    GetFeedFeedSiteGoogle,
    GetFeedFeedSiteGoogleDrive,
    GetFeedFeedSiteOneDrive,
    GetFeedFeedSiteS3,
    GetFeedFeedSiteSharePoint,
    GetFeedFeedSlack,
    GetFeedFeedWeb,
    GetFeedFeedWorkflow,
    GetFeedFeedYoutube,
)
from .get_label import GetLabel, GetLabelLabel
from .get_medical_condition import (
    GetMedicalCondition,
    GetMedicalConditionMedicalCondition,
)
from .get_medical_contraindication import (
    GetMedicalContraindication,
    GetMedicalContraindicationMedicalContraindication,
)
from .get_medical_device import GetMedicalDevice, GetMedicalDeviceMedicalDevice
from .get_medical_drug import GetMedicalDrug, GetMedicalDrugMedicalDrug
from .get_medical_drug_class import (
    GetMedicalDrugClass,
    GetMedicalDrugClassMedicalDrugClass,
)
from .get_medical_guideline import (
    GetMedicalGuideline,
    GetMedicalGuidelineMedicalGuideline,
)
from .get_medical_indication import (
    GetMedicalIndication,
    GetMedicalIndicationMedicalIndication,
)
from .get_medical_procedure import (
    GetMedicalProcedure,
    GetMedicalProcedureMedicalProcedure,
)
from .get_medical_study import (
    GetMedicalStudy,
    GetMedicalStudyMedicalStudy,
    GetMedicalStudyMedicalStudyAddress,
)
from .get_medical_test import GetMedicalTest, GetMedicalTestMedicalTest
from .get_medical_therapy import GetMedicalTherapy, GetMedicalTherapyMedicalTherapy
from .get_organization import (
    GetOrganization,
    GetOrganizationOrganization,
    GetOrganizationOrganizationAddress,
)
from .get_person import GetPerson, GetPersonPerson, GetPersonPersonAddress
from .get_place import GetPlace, GetPlacePlace, GetPlacePlaceAddress
from .get_product import GetProduct, GetProductProduct, GetProductProductAddress
from .get_project import (
    GetProject,
    GetProjectProject,
    GetProjectProjectQuota,
    GetProjectProjectSpecification,
    GetProjectProjectWorkflow,
)
from .get_repo import GetRepo, GetRepoRepo
from .get_share_point_consent_uri import (
    GetSharePointConsentUri,
    GetSharePointConsentUriSharePointConsentUri,
)
from .get_software import GetSoftware, GetSoftwareSoftware
from .get_specification import (
    GetSpecification,
    GetSpecificationSpecification,
    GetSpecificationSpecificationAnthropic,
    GetSpecificationSpecificationAzureOpenAi,
    GetSpecificationSpecificationCohere,
    GetSpecificationSpecificationDeepseek,
    GetSpecificationSpecificationGraphStrategy,
    GetSpecificationSpecificationGroq,
    GetSpecificationSpecificationMistral,
    GetSpecificationSpecificationOpenAi,
    GetSpecificationSpecificationOwner,
    GetSpecificationSpecificationPromptStrategy,
    GetSpecificationSpecificationReplicate,
    GetSpecificationSpecificationRerankingStrategy,
    GetSpecificationSpecificationRetrievalStrategy,
    GetSpecificationSpecificationRevisionStrategy,
    GetSpecificationSpecificationStrategy,
    GetSpecificationSpecificationTools,
)
from .get_workflow import (
    GetWorkflow,
    GetWorkflowWorkflow,
    GetWorkflowWorkflowActions,
    GetWorkflowWorkflowActionsConnector,
    GetWorkflowWorkflowActionsConnectorSlack,
    GetWorkflowWorkflowEnrichment,
    GetWorkflowWorkflowEnrichmentJobs,
    GetWorkflowWorkflowEnrichmentJobsConnector,
    GetWorkflowWorkflowEnrichmentJobsConnectorFhir,
    GetWorkflowWorkflowEnrichmentLink,
    GetWorkflowWorkflowExtraction,
    GetWorkflowWorkflowExtractionJobs,
    GetWorkflowWorkflowExtractionJobsConnector,
    GetWorkflowWorkflowExtractionJobsConnectorAzureImage,
    GetWorkflowWorkflowExtractionJobsConnectorAzureText,
    GetWorkflowWorkflowExtractionJobsConnectorModelImage,
    GetWorkflowWorkflowExtractionJobsConnectorModelImageSpecification,
    GetWorkflowWorkflowExtractionJobsConnectorModelText,
    GetWorkflowWorkflowExtractionJobsConnectorModelTextSpecification,
    GetWorkflowWorkflowExtractionJobsConnectorOpenAiImage,
    GetWorkflowWorkflowIndexing,
    GetWorkflowWorkflowIndexingJobs,
    GetWorkflowWorkflowIndexingJobsConnector,
    GetWorkflowWorkflowIngestion,
    GetWorkflowWorkflowIngestionCollections,
    GetWorkflowWorkflowIngestionIf,
    GetWorkflowWorkflowOwner,
    GetWorkflowWorkflowPreparation,
    GetWorkflowWorkflowPreparationJobs,
    GetWorkflowWorkflowPreparationJobsConnector,
    GetWorkflowWorkflowPreparationJobsConnectorAzureDocument,
    GetWorkflowWorkflowPreparationJobsConnectorDeepgram,
    GetWorkflowWorkflowPreparationJobsConnectorDocument,
    GetWorkflowWorkflowPreparationJobsConnectorEmail,
    GetWorkflowWorkflowPreparationJobsConnectorModelDocument,
    GetWorkflowWorkflowPreparationJobsConnectorModelDocumentSpecification,
    GetWorkflowWorkflowPreparationSummarizations,
    GetWorkflowWorkflowPreparationSummarizationsSpecification,
    GetWorkflowWorkflowStorage,
    GetWorkflowWorkflowStorageEmbeddings,
)
from .ingest_encoded_file import (
    IngestEncodedFile,
    IngestEncodedFileIngestEncodedFile,
    IngestEncodedFileIngestEncodedFileCollections,
)
from .ingest_text import (
    IngestText,
    IngestTextIngestText,
    IngestTextIngestTextCollections,
)
from .ingest_uri import IngestUri, IngestUriIngestUri, IngestUriIngestUriCollections
from .input_types import (
    AddressFilter,
    AddressInput,
    AlertFilter,
    AlertInput,
    AlertSchedulePolicyInput,
    AlertUpdateInput,
    AmazonFeedPropertiesInput,
    AmazonFeedPropertiesUpdateInput,
    AnthropicModelPropertiesInput,
    AnthropicModelPropertiesUpdateInput,
    AtlassianJiraFeedPropertiesInput,
    AtlassianJiraFeedPropertiesUpdateInput,
    AudioMetadataInput,
    AzureBlobFeedPropertiesInput,
    AzureBlobFeedPropertiesUpdateInput,
    AzureDocumentPreparationPropertiesInput,
    AzureFileFeedPropertiesInput,
    AzureFileFeedPropertiesUpdateInput,
    AzureImageExtractionPropertiesInput,
    AzureOpenAIModelPropertiesInput,
    AzureOpenAIModelPropertiesUpdateInput,
    AzureTextExtractionPropertiesInput,
    BoundingBoxInput,
    CategoryFacetInput,
    CategoryFilter,
    CategoryInput,
    CategoryUpdateInput,
    CohereModelPropertiesInput,
    CohereModelPropertiesUpdateInput,
    CollectionFilter,
    CollectionInput,
    CollectionUpdateInput,
    ContentCriteriaInput,
    ContentCriteriaLevelInput,
    ContentFacetInput,
    ContentFilter,
    ContentFilterLevel,
    ContentGraphInput,
    ContentIndexingConnectorInput,
    ContentInput,
    ContentPublishingConnectorInput,
    ContentPublishingConnectorUpdateInput,
    ContentUpdateInput,
    ConversationFilter,
    ConversationInput,
    ConversationStrategyInput,
    ConversationStrategyUpdateInput,
    ConversationUpdateInput,
    DateRangeFilter,
    DateRangeInput,
    DeepgramAudioPreparationPropertiesInput,
    DeepseekModelPropertiesInput,
    DeepseekModelPropertiesUpdateInput,
    DiscordFeedPropertiesInput,
    DiscordFeedPropertiesUpdateInput,
    DocumentMetadataInput,
    DocumentPreparationPropertiesInput,
    DrawingMetadataInput,
    ElevenLabsPublishingPropertiesInput,
    EmailFeedPropertiesInput,
    EmailFeedPropertiesUpdateInput,
    EmailMetadataInput,
    EmailPreparationPropertiesInput,
    EmbeddingsStrategyInput,
    EnrichmentWorkflowJobInput,
    EnrichmentWorkflowStageInput,
    EntityEnrichmentConnectorInput,
    EntityExtractionConnectorInput,
    EntityReferenceFilter,
    EntityReferenceInput,
    EventFacetInput,
    EventFilter,
    EventInput,
    EventUpdateInput,
    ExtractionWorkflowJobInput,
    ExtractionWorkflowStageInput,
    FeedFilter,
    FeedInput,
    FeedSchedulePolicyInput,
    FeedUpdateInput,
    FHIREnrichmentPropertiesInput,
    FilePreparationConnectorInput,
    GeometryMetadataInput,
    GitHubIssuesFeedPropertiesInput,
    GitHubIssuesFeedPropertiesUpdateInput,
    GoogleDriveFeedPropertiesInput,
    GoogleDriveFeedPropertiesUpdateInput,
    GoogleEmailFeedPropertiesInput,
    GoogleEmailFeedPropertiesUpdateInput,
    GoogleFeedPropertiesInput,
    GoogleFeedPropertiesUpdateInput,
    GraphStrategyInput,
    GraphStrategyUpdateInput,
    GroqModelPropertiesInput,
    GroqModelPropertiesUpdateInput,
    H3Filter,
    H3IndexFilter,
    ImageMetadataInput,
    IndexingWorkflowJobInput,
    IndexingWorkflowStageInput,
    IngestionContentFilterInput,
    IngestionWorkflowStageInput,
    Int64RangeFilter,
    IntegrationConnectorInput,
    IntegrationConnectorUpdateInput,
    IssueFeedPropertiesInput,
    IssueFeedPropertiesUpdateInput,
    IssueMetadataInput,
    LabelFacetInput,
    LabelFilter,
    LabelInput,
    LabelUpdateInput,
    LanguageMetadataInput,
    LinearFeedPropertiesInput,
    LinearFeedPropertiesUpdateInput,
    LinkStrategyInput,
    MedicalConditionFacetInput,
    MedicalConditionFilter,
    MedicalConditionInput,
    MedicalConditionUpdateInput,
    MedicalContraindicationFacetInput,
    MedicalContraindicationFilter,
    MedicalContraindicationInput,
    MedicalContraindicationUpdateInput,
    MedicalDeviceFacetInput,
    MedicalDeviceFilter,
    MedicalDeviceInput,
    MedicalDeviceUpdateInput,
    MedicalDrugClassFacetInput,
    MedicalDrugClassFilter,
    MedicalDrugClassInput,
    MedicalDrugClassUpdateInput,
    MedicalDrugFacetInput,
    MedicalDrugFilter,
    MedicalDrugInput,
    MedicalDrugUpdateInput,
    MedicalGuidelineFacetInput,
    MedicalGuidelineFilter,
    MedicalGuidelineInput,
    MedicalGuidelineUpdateInput,
    MedicalIndicationFacetInput,
    MedicalIndicationFilter,
    MedicalIndicationInput,
    MedicalIndicationUpdateInput,
    MedicalProcedureFacetInput,
    MedicalProcedureFilter,
    MedicalProcedureInput,
    MedicalProcedureUpdateInput,
    MedicalStudyFacetInput,
    MedicalStudyFilter,
    MedicalStudyInput,
    MedicalStudyUpdateInput,
    MedicalTestFacetInput,
    MedicalTestFilter,
    MedicalTestInput,
    MedicalTestUpdateInput,
    MedicalTherapyFacetInput,
    MedicalTherapyFilter,
    MedicalTherapyInput,
    MedicalTherapyUpdateInput,
    MetadataFilter,
    MetadataInput,
    MetadataUpdateInput,
    MicrosoftEmailFeedPropertiesInput,
    MicrosoftEmailFeedPropertiesUpdateInput,
    MicrosoftTeamsChannelsInput,
    MicrosoftTeamsFeedPropertiesInput,
    MicrosoftTeamsFeedPropertiesUpdateInput,
    MicrosoftTeamsTeamsInput,
    MistralModelPropertiesInput,
    MistralModelPropertiesUpdateInput,
    ModelDocumentPreparationInputProperties,
    ModelImageExtractionPropertiesInput,
    ModelTextExtractionPropertiesInput,
    NamedEntityReferenceInput,
    NotionFeedPropertiesInput,
    NotionFeedPropertiesUpdateInput,
    ObservationCriteriaInput,
    ObservationInput,
    ObservationOccurrenceInput,
    ObservationReferenceFilter,
    ObservationUpdateInput,
    OneDriveFeedPropertiesInput,
    OneDriveFeedPropertiesUpdateInput,
    OneDriveFoldersInput,
    OpenAIImageExtractionPropertiesInput,
    OpenAIModelPropertiesInput,
    OpenAIModelPropertiesUpdateInput,
    OrganizationFacetInput,
    OrganizationFilter,
    OrganizationInput,
    OrganizationUpdateInput,
    PackageMetadataInput,
    PersonFacetInput,
    PersonFilter,
    PersonInput,
    PersonUpdateInput,
    PlaceFacetInput,
    PlaceFilter,
    PlaceInput,
    PlaceUpdateInput,
    PointCloudMetadataInput,
    PointFilter,
    PointInput,
    PreparationWorkflowJobInput,
    PreparationWorkflowStageInput,
    ProductFacetInput,
    ProductFilter,
    ProductInput,
    ProductUpdateInput,
    ProjectFilter,
    ProjectInput,
    ProjectQuotaInput,
    ProjectUpdateInput,
    PromptStrategyInput,
    PromptStrategyUpdateInput,
    RedditFeedPropertiesInput,
    RedditFeedPropertiesUpdateInput,
    ReplicateModelPropertiesInput,
    ReplicateModelPropertiesUpdateInput,
    RepoFacetInput,
    RepoFilter,
    RepoInput,
    RepoUpdateInput,
    RerankingStrategyInput,
    RerankingStrategyUpdateInput,
    RetrievalStrategyInput,
    RetrievalStrategyUpdateInput,
    RevisionStrategyInput,
    RevisionStrategyUpdateInput,
    RSSFeedPropertiesInput,
    RSSFeedPropertiesUpdateInput,
    SearchFeedPropertiesInput,
    SearchFeedPropertiesUpdateInput,
    ShapeMetadataInput,
    SharePointFeedPropertiesInput,
    SharePointFeedPropertiesUpdateInput,
    SharePointFoldersInput,
    SharePointLibrariesInput,
    SiteFeedPropertiesInput,
    SiteFeedPropertiesUpdateInput,
    SlackChannelsInput,
    SlackFeedPropertiesInput,
    SlackFeedPropertiesUpdateInput,
    SlackIntegrationPropertiesInput,
    SoftwareFacetInput,
    SoftwareFilter,
    SoftwareInput,
    SoftwareUpdateInput,
    SpecificationFilter,
    SpecificationInput,
    SpecificationUpdateInput,
    StorageWorkflowStageInput,
    SummarizationStrategyInput,
    ToolDefinitionInput,
    ToolDefinitionUpdateInput,
    VideoMetadataInput,
    WebFeedPropertiesInput,
    WebFeedPropertiesUpdateInput,
    WorkflowActionInput,
    WorkflowFilter,
    WorkflowInput,
    WorkflowUpdateInput,
    YouTubeFeedPropertiesInput,
    YouTubeFeedPropertiesUpdateInput,
)
from .is_content_done import IsContentDone, IsContentDoneIsContentDone
from .is_feed_done import IsFeedDone, IsFeedDoneIsFeedDone
from .lookup_credits import LookupCredits, LookupCreditsLookupCredits
from .lookup_usage import LookupUsage, LookupUsageLookupUsage
from .operations import (
    ADD_CONTENTS_TO_COLLECTIONS_GQL,
    CLEAR_CONVERSATION_GQL,
    CLOSE_CONVERSATION_GQL,
    COUNT_ALERTS_GQL,
    COUNT_CATEGORIES_GQL,
    COUNT_COLLECTIONS_GQL,
    COUNT_CONTENTS_GQL,
    COUNT_CONVERSATIONS_GQL,
    COUNT_EVENTS_GQL,
    COUNT_FEEDS_GQL,
    COUNT_LABELS_GQL,
    COUNT_MEDICAL_CONDITIONS_GQL,
    COUNT_MEDICAL_CONTRAINDICATIONS_GQL,
    COUNT_MEDICAL_DEVICES_GQL,
    COUNT_MEDICAL_DRUG_CLASSES_GQL,
    COUNT_MEDICAL_DRUGS_GQL,
    COUNT_MEDICAL_GUIDELINES_GQL,
    COUNT_MEDICAL_INDICATIONS_GQL,
    COUNT_MEDICAL_PROCEDURES_GQL,
    COUNT_MEDICAL_STUDIES_GQL,
    COUNT_MEDICAL_TESTS_GQL,
    COUNT_MEDICAL_THERAPIES_GQL,
    COUNT_ORGANIZATIONS_GQL,
    COUNT_PERSONS_GQL,
    COUNT_PLACES_GQL,
    COUNT_PRODUCTS_GQL,
    COUNT_REPOS_GQL,
    COUNT_SOFTWARES_GQL,
    COUNT_SPECIFICATIONS_GQL,
    COUNT_WORKFLOWS_GQL,
    CREATE_ALERT_GQL,
    CREATE_CATEGORY_GQL,
    CREATE_COLLECTION_GQL,
    CREATE_CONVERSATION_GQL,
    CREATE_EVENT_GQL,
    CREATE_FEED_GQL,
    CREATE_LABEL_GQL,
    CREATE_MEDICAL_CONDITION_GQL,
    CREATE_MEDICAL_CONTRAINDICATION_GQL,
    CREATE_MEDICAL_DEVICE_GQL,
    CREATE_MEDICAL_DRUG_CLASS_GQL,
    CREATE_MEDICAL_DRUG_GQL,
    CREATE_MEDICAL_GUIDELINE_GQL,
    CREATE_MEDICAL_INDICATION_GQL,
    CREATE_MEDICAL_PROCEDURE_GQL,
    CREATE_MEDICAL_STUDY_GQL,
    CREATE_MEDICAL_TEST_GQL,
    CREATE_MEDICAL_THERAPY_GQL,
    CREATE_OBSERVATION_GQL,
    CREATE_ORGANIZATION_GQL,
    CREATE_PERSON_GQL,
    CREATE_PLACE_GQL,
    CREATE_PRODUCT_GQL,
    CREATE_REPO_GQL,
    CREATE_SOFTWARE_GQL,
    CREATE_SPECIFICATION_GQL,
    CREATE_WORKFLOW_GQL,
    DELETE_ALERT_GQL,
    DELETE_ALERTS_GQL,
    DELETE_ALL_ALERTS_GQL,
    DELETE_ALL_CATEGORIES_GQL,
    DELETE_ALL_COLLECTIONS_GQL,
    DELETE_ALL_CONTENTS_GQL,
    DELETE_ALL_CONVERSATIONS_GQL,
    DELETE_ALL_EVENTS_GQL,
    DELETE_ALL_FEEDS_GQL,
    DELETE_ALL_LABELS_GQL,
    DELETE_ALL_MEDICAL_CONDITIONS_GQL,
    DELETE_ALL_MEDICAL_CONTRAINDICATIONS_GQL,
    DELETE_ALL_MEDICAL_DEVICES_GQL,
    DELETE_ALL_MEDICAL_DRUG_CLASSES_GQL,
    DELETE_ALL_MEDICAL_DRUGS_GQL,
    DELETE_ALL_MEDICAL_GUIDELINES_GQL,
    DELETE_ALL_MEDICAL_INDICATIONS_GQL,
    DELETE_ALL_MEDICAL_PROCEDURES_GQL,
    DELETE_ALL_MEDICAL_STUDIES_GQL,
    DELETE_ALL_MEDICAL_TESTS_GQL,
    DELETE_ALL_MEDICAL_THERAPIES_GQL,
    DELETE_ALL_ORGANIZATIONS_GQL,
    DELETE_ALL_PERSONS_GQL,
    DELETE_ALL_PLACES_GQL,
    DELETE_ALL_PRODUCTS_GQL,
    DELETE_ALL_REPOS_GQL,
    DELETE_ALL_SOFTWARES_GQL,
    DELETE_ALL_SPECIFICATIONS_GQL,
    DELETE_ALL_WORKFLOWS_GQL,
    DELETE_CATEGORIES_GQL,
    DELETE_CATEGORY_GQL,
    DELETE_COLLECTION_GQL,
    DELETE_COLLECTIONS_GQL,
    DELETE_CONTENT_GQL,
    DELETE_CONTENTS_GQL,
    DELETE_CONVERSATION_GQL,
    DELETE_CONVERSATIONS_GQL,
    DELETE_EVENT_GQL,
    DELETE_EVENTS_GQL,
    DELETE_FEED_GQL,
    DELETE_FEEDS_GQL,
    DELETE_LABEL_GQL,
    DELETE_LABELS_GQL,
    DELETE_MEDICAL_CONDITION_GQL,
    DELETE_MEDICAL_CONDITIONS_GQL,
    DELETE_MEDICAL_CONTRAINDICATION_GQL,
    DELETE_MEDICAL_CONTRAINDICATIONS_GQL,
    DELETE_MEDICAL_DEVICE_GQL,
    DELETE_MEDICAL_DEVICES_GQL,
    DELETE_MEDICAL_DRUG_CLASS_GQL,
    DELETE_MEDICAL_DRUG_CLASSES_GQL,
    DELETE_MEDICAL_DRUG_GQL,
    DELETE_MEDICAL_DRUGS_GQL,
    DELETE_MEDICAL_GUIDELINE_GQL,
    DELETE_MEDICAL_GUIDELINES_GQL,
    DELETE_MEDICAL_INDICATION_GQL,
    DELETE_MEDICAL_INDICATIONS_GQL,
    DELETE_MEDICAL_PROCEDURE_GQL,
    DELETE_MEDICAL_PROCEDURES_GQL,
    DELETE_MEDICAL_STUDIES_GQL,
    DELETE_MEDICAL_STUDY_GQL,
    DELETE_MEDICAL_TEST_GQL,
    DELETE_MEDICAL_TESTS_GQL,
    DELETE_MEDICAL_THERAPIES_GQL,
    DELETE_MEDICAL_THERAPY_GQL,
    DELETE_OBSERVATION_GQL,
    DELETE_ORGANIZATION_GQL,
    DELETE_ORGANIZATIONS_GQL,
    DELETE_PERSON_GQL,
    DELETE_PERSONS_GQL,
    DELETE_PLACE_GQL,
    DELETE_PLACES_GQL,
    DELETE_PRODUCT_GQL,
    DELETE_PRODUCTS_GQL,
    DELETE_REPO_GQL,
    DELETE_REPOS_GQL,
    DELETE_SOFTWARE_GQL,
    DELETE_SOFTWARES_GQL,
    DELETE_SPECIFICATION_GQL,
    DELETE_SPECIFICATIONS_GQL,
    DELETE_WORKFLOW_GQL,
    DELETE_WORKFLOWS_GQL,
    DISABLE_ALERT_GQL,
    DISABLE_FEED_GQL,
    ENABLE_ALERT_GQL,
    ENABLE_FEED_GQL,
    EXTRACT_CONTENTS_GQL,
    GET_ALERT_GQL,
    GET_CATEGORY_GQL,
    GET_COLLECTION_GQL,
    GET_CONTENT_GQL,
    GET_CONVERSATION_GQL,
    GET_EVENT_GQL,
    GET_FEED_GQL,
    GET_LABEL_GQL,
    GET_MEDICAL_CONDITION_GQL,
    GET_MEDICAL_CONTRAINDICATION_GQL,
    GET_MEDICAL_DEVICE_GQL,
    GET_MEDICAL_DRUG_CLASS_GQL,
    GET_MEDICAL_DRUG_GQL,
    GET_MEDICAL_GUIDELINE_GQL,
    GET_MEDICAL_INDICATION_GQL,
    GET_MEDICAL_PROCEDURE_GQL,
    GET_MEDICAL_STUDY_GQL,
    GET_MEDICAL_TEST_GQL,
    GET_MEDICAL_THERAPY_GQL,
    GET_ORGANIZATION_GQL,
    GET_PERSON_GQL,
    GET_PLACE_GQL,
    GET_PRODUCT_GQL,
    GET_PROJECT_GQL,
    GET_REPO_GQL,
    GET_SHARE_POINT_CONSENT_URI_GQL,
    GET_SOFTWARE_GQL,
    GET_SPECIFICATION_GQL,
    GET_WORKFLOW_GQL,
    INGEST_ENCODED_FILE_GQL,
    INGEST_TEXT_GQL,
    INGEST_URI_GQL,
    IS_CONTENT_DONE_GQL,
    IS_FEED_DONE_GQL,
    LOOKUP_CREDITS_GQL,
    LOOKUP_USAGE_GQL,
    PROMPT_CONVERSATION_GQL,
    PROMPT_SPECIFICATIONS_GQL,
    PUBLISH_CONTENTS_GQL,
    PUBLISH_CONVERSATION_GQL,
    PUBLISH_TEXT_GQL,
    QUERY_ALERTS_GQL,
    QUERY_CATEGORIES_GQL,
    QUERY_COLLECTIONS_GQL,
    QUERY_CONTENTS_FACETS_GQL,
    QUERY_CONTENTS_GQL,
    QUERY_CONTENTS_GRAPH_GQL,
    QUERY_CONVERSATIONS_GQL,
    QUERY_CREDITS_GQL,
    QUERY_EVENTS_GQL,
    QUERY_FEEDS_GQL,
    QUERY_LABELS_GQL,
    QUERY_MEDICAL_CONDITIONS_GQL,
    QUERY_MEDICAL_CONTRAINDICATIONS_GQL,
    QUERY_MEDICAL_DEVICES_GQL,
    QUERY_MEDICAL_DRUG_CLASSES_GQL,
    QUERY_MEDICAL_DRUGS_GQL,
    QUERY_MEDICAL_GUIDELINES_GQL,
    QUERY_MEDICAL_INDICATIONS_GQL,
    QUERY_MEDICAL_PROCEDURES_GQL,
    QUERY_MEDICAL_STUDIES_GQL,
    QUERY_MEDICAL_TESTS_GQL,
    QUERY_MEDICAL_THERAPIES_GQL,
    QUERY_MICROSOFT_TEAMS_CHANNELS_GQL,
    QUERY_MICROSOFT_TEAMS_TEAMS_GQL,
    QUERY_ONE_DRIVE_FOLDERS_GQL,
    QUERY_ORGANIZATIONS_GQL,
    QUERY_PERSONS_GQL,
    QUERY_PLACES_GQL,
    QUERY_PRODUCTS_GQL,
    QUERY_REPOS_GQL,
    QUERY_SHARE_POINT_FOLDERS_GQL,
    QUERY_SHARE_POINT_LIBRARIES_GQL,
    QUERY_SOFTWARES_GQL,
    QUERY_SPECIFICATIONS_GQL,
    QUERY_USAGE_GQL,
    QUERY_WORKFLOWS_GQL,
    REMOVE_CONTENTS_FROM_COLLECTION_GQL,
    SUGGEST_CONVERSATION_GQL,
    SUMMARIZE_CONTENTS_GQL,
    UPDATE_ALERT_GQL,
    UPDATE_CATEGORY_GQL,
    UPDATE_COLLECTION_GQL,
    UPDATE_CONTENT_GQL,
    UPDATE_CONVERSATION_GQL,
    UPDATE_EVENT_GQL,
    UPDATE_FEED_GQL,
    UPDATE_LABEL_GQL,
    UPDATE_MEDICAL_CONDITION_GQL,
    UPDATE_MEDICAL_CONTRAINDICATION_GQL,
    UPDATE_MEDICAL_DEVICE_GQL,
    UPDATE_MEDICAL_DRUG_CLASS_GQL,
    UPDATE_MEDICAL_DRUG_GQL,
    UPDATE_MEDICAL_GUIDELINE_GQL,
    UPDATE_MEDICAL_INDICATION_GQL,
    UPDATE_MEDICAL_PROCEDURE_GQL,
    UPDATE_MEDICAL_STUDY_GQL,
    UPDATE_MEDICAL_TEST_GQL,
    UPDATE_MEDICAL_THERAPY_GQL,
    UPDATE_OBSERVATION_GQL,
    UPDATE_ORGANIZATION_GQL,
    UPDATE_PERSON_GQL,
    UPDATE_PLACE_GQL,
    UPDATE_PRODUCT_GQL,
    UPDATE_PROJECT_GQL,
    UPDATE_REPO_GQL,
    UPDATE_SOFTWARE_GQL,
    UPDATE_SPECIFICATION_GQL,
    UPDATE_WORKFLOW_GQL,
)
from .prompt_conversation import (
    PromptConversation,
    PromptConversationPromptConversation,
    PromptConversationPromptConversationConversation,
    PromptConversationPromptConversationFacets,
    PromptConversationPromptConversationFacetsObservable,
    PromptConversationPromptConversationFacetsObservableObservable,
    PromptConversationPromptConversationFacetsRange,
    PromptConversationPromptConversationGraph,
    PromptConversationPromptConversationGraphEdges,
    PromptConversationPromptConversationGraphNodes,
    PromptConversationPromptConversationMessage,
    PromptConversationPromptConversationMessageCitations,
    PromptConversationPromptConversationMessageCitationsContent,
    PromptConversationPromptConversationMessageCitationsContentAudio,
    PromptConversationPromptConversationMessageCitationsContentDocument,
    PromptConversationPromptConversationMessageCitationsContentImage,
    PromptConversationPromptConversationMessageCitationsContentVideo,
)
from .prompt_specifications import (
    PromptSpecifications,
    PromptSpecificationsPromptSpecifications,
    PromptSpecificationsPromptSpecificationsMessages,
    PromptSpecificationsPromptSpecificationsMessagesCitations,
    PromptSpecificationsPromptSpecificationsMessagesCitationsContent,
    PromptSpecificationsPromptSpecificationsMessagesCitationsContentAudio,
    PromptSpecificationsPromptSpecificationsMessagesCitationsContentDocument,
    PromptSpecificationsPromptSpecificationsMessagesCitationsContentImage,
    PromptSpecificationsPromptSpecificationsMessagesCitationsContentVideo,
    PromptSpecificationsPromptSpecificationsSpecification,
)
from .publish_contents import (
    PublishContents,
    PublishContentsPublishContents,
    PublishContentsPublishContentsCollections,
)
from .publish_conversation import (
    PublishConversation,
    PublishConversationPublishConversation,
    PublishConversationPublishConversationCollections,
)
from .publish_text import (
    PublishText,
    PublishTextPublishText,
    PublishTextPublishTextCollections,
)
from .query_alerts import (
    QueryAlerts,
    QueryAlertsAlerts,
    QueryAlertsAlertsResults,
    QueryAlertsAlertsResultsFilter,
    QueryAlertsAlertsResultsFilterAnd,
    QueryAlertsAlertsResultsFilterAndCollections,
    QueryAlertsAlertsResultsFilterAndFeeds,
    QueryAlertsAlertsResultsFilterAndObservations,
    QueryAlertsAlertsResultsFilterAndObservationsObservable,
    QueryAlertsAlertsResultsFilterAndWorkflows,
    QueryAlertsAlertsResultsFilterCollections,
    QueryAlertsAlertsResultsFilterContents,
    QueryAlertsAlertsResultsFilterCreationDateRange,
    QueryAlertsAlertsResultsFilterDateRange,
    QueryAlertsAlertsResultsFilterFeeds,
    QueryAlertsAlertsResultsFilterObservations,
    QueryAlertsAlertsResultsFilterObservationsObservable,
    QueryAlertsAlertsResultsFilterOr,
    QueryAlertsAlertsResultsFilterOrCollections,
    QueryAlertsAlertsResultsFilterOrFeeds,
    QueryAlertsAlertsResultsFilterOrObservations,
    QueryAlertsAlertsResultsFilterOrObservationsObservable,
    QueryAlertsAlertsResultsFilterOrWorkflows,
    QueryAlertsAlertsResultsFilterWorkflows,
    QueryAlertsAlertsResultsIntegration,
    QueryAlertsAlertsResultsIntegrationSlack,
    QueryAlertsAlertsResultsOwner,
    QueryAlertsAlertsResultsPublishing,
    QueryAlertsAlertsResultsPublishingElevenLabs,
    QueryAlertsAlertsResultsPublishSpecification,
    QueryAlertsAlertsResultsSummarySpecification,
)
from .query_categories import (
    QueryCategories,
    QueryCategoriesCategories,
    QueryCategoriesCategoriesResults,
)
from .query_collections import (
    QueryCollections,
    QueryCollectionsCollections,
    QueryCollectionsCollectionsResults,
    QueryCollectionsCollectionsResultsContents,
    QueryCollectionsCollectionsResultsOwner,
)
from .query_contents import (
    QueryContents,
    QueryContentsContents,
    QueryContentsContentsResults,
    QueryContentsContentsResultsAddress,
    QueryContentsContentsResultsAudio,
    QueryContentsContentsResultsChildren,
    QueryContentsContentsResultsCollections,
    QueryContentsContentsResultsDocument,
    QueryContentsContentsResultsEmail,
    QueryContentsContentsResultsEmailBcc,
    QueryContentsContentsResultsEmailCc,
    QueryContentsContentsResultsEmailFrom,
    QueryContentsContentsResultsEmailTo,
    QueryContentsContentsResultsFeed,
    QueryContentsContentsResultsImage,
    QueryContentsContentsResultsIssue,
    QueryContentsContentsResultsLanguage,
    QueryContentsContentsResultsLinks,
    QueryContentsContentsResultsLocation,
    QueryContentsContentsResultsObservations,
    QueryContentsContentsResultsObservationsObservable,
    QueryContentsContentsResultsObservationsOccurrences,
    QueryContentsContentsResultsObservationsOccurrencesBoundingBox,
    QueryContentsContentsResultsObservationsRelated,
    QueryContentsContentsResultsOwner,
    QueryContentsContentsResultsPackage,
    QueryContentsContentsResultsPages,
    QueryContentsContentsResultsPagesChunks,
    QueryContentsContentsResultsParent,
    QueryContentsContentsResultsSegments,
    QueryContentsContentsResultsVideo,
    QueryContentsContentsResultsWorkflow,
)
from .query_contents_facets import (
    QueryContentsFacets,
    QueryContentsFacetsContents,
    QueryContentsFacetsContentsFacets,
    QueryContentsFacetsContentsFacetsObservable,
    QueryContentsFacetsContentsFacetsObservableObservable,
    QueryContentsFacetsContentsFacetsRange,
    QueryContentsFacetsContentsResults,
    QueryContentsFacetsContentsResultsAddress,
    QueryContentsFacetsContentsResultsAudio,
    QueryContentsFacetsContentsResultsChildren,
    QueryContentsFacetsContentsResultsCollections,
    QueryContentsFacetsContentsResultsDocument,
    QueryContentsFacetsContentsResultsEmail,
    QueryContentsFacetsContentsResultsEmailBcc,
    QueryContentsFacetsContentsResultsEmailCc,
    QueryContentsFacetsContentsResultsEmailFrom,
    QueryContentsFacetsContentsResultsEmailTo,
    QueryContentsFacetsContentsResultsFeed,
    QueryContentsFacetsContentsResultsImage,
    QueryContentsFacetsContentsResultsIssue,
    QueryContentsFacetsContentsResultsLanguage,
    QueryContentsFacetsContentsResultsLinks,
    QueryContentsFacetsContentsResultsLocation,
    QueryContentsFacetsContentsResultsObservations,
    QueryContentsFacetsContentsResultsObservationsObservable,
    QueryContentsFacetsContentsResultsObservationsOccurrences,
    QueryContentsFacetsContentsResultsObservationsOccurrencesBoundingBox,
    QueryContentsFacetsContentsResultsObservationsRelated,
    QueryContentsFacetsContentsResultsOwner,
    QueryContentsFacetsContentsResultsPackage,
    QueryContentsFacetsContentsResultsPages,
    QueryContentsFacetsContentsResultsPagesChunks,
    QueryContentsFacetsContentsResultsParent,
    QueryContentsFacetsContentsResultsSegments,
    QueryContentsFacetsContentsResultsVideo,
    QueryContentsFacetsContentsResultsWorkflow,
)
from .query_contents_graph import (
    QueryContentsGraph,
    QueryContentsGraphContents,
    QueryContentsGraphContentsGraph,
    QueryContentsGraphContentsGraphEdges,
    QueryContentsGraphContentsGraphNodes,
)
from .query_conversations import (
    QueryConversations,
    QueryConversationsConversations,
    QueryConversationsConversationsResults,
    QueryConversationsConversationsResultsAugmentedFilter,
    QueryConversationsConversationsResultsAugmentedFilterAnd,
    QueryConversationsConversationsResultsAugmentedFilterAndCollections,
    QueryConversationsConversationsResultsAugmentedFilterAndFeeds,
    QueryConversationsConversationsResultsAugmentedFilterAndObservations,
    QueryConversationsConversationsResultsAugmentedFilterAndObservationsObservable,
    QueryConversationsConversationsResultsAugmentedFilterAndWorkflows,
    QueryConversationsConversationsResultsAugmentedFilterCollections,
    QueryConversationsConversationsResultsAugmentedFilterContents,
    QueryConversationsConversationsResultsAugmentedFilterCreationDateRange,
    QueryConversationsConversationsResultsAugmentedFilterDateRange,
    QueryConversationsConversationsResultsAugmentedFilterFeeds,
    QueryConversationsConversationsResultsAugmentedFilterObservations,
    QueryConversationsConversationsResultsAugmentedFilterObservationsObservable,
    QueryConversationsConversationsResultsAugmentedFilterOr,
    QueryConversationsConversationsResultsAugmentedFilterOrCollections,
    QueryConversationsConversationsResultsAugmentedFilterOrFeeds,
    QueryConversationsConversationsResultsAugmentedFilterOrObservations,
    QueryConversationsConversationsResultsAugmentedFilterOrObservationsObservable,
    QueryConversationsConversationsResultsAugmentedFilterOrWorkflows,
    QueryConversationsConversationsResultsAugmentedFilterWorkflows,
    QueryConversationsConversationsResultsFilter,
    QueryConversationsConversationsResultsFilterAnd,
    QueryConversationsConversationsResultsFilterAndCollections,
    QueryConversationsConversationsResultsFilterAndFeeds,
    QueryConversationsConversationsResultsFilterAndObservations,
    QueryConversationsConversationsResultsFilterAndObservationsObservable,
    QueryConversationsConversationsResultsFilterAndWorkflows,
    QueryConversationsConversationsResultsFilterCollections,
    QueryConversationsConversationsResultsFilterContents,
    QueryConversationsConversationsResultsFilterCreationDateRange,
    QueryConversationsConversationsResultsFilterDateRange,
    QueryConversationsConversationsResultsFilterFeeds,
    QueryConversationsConversationsResultsFilterObservations,
    QueryConversationsConversationsResultsFilterObservationsObservable,
    QueryConversationsConversationsResultsFilterOr,
    QueryConversationsConversationsResultsFilterOrCollections,
    QueryConversationsConversationsResultsFilterOrFeeds,
    QueryConversationsConversationsResultsFilterOrObservations,
    QueryConversationsConversationsResultsFilterOrObservationsObservable,
    QueryConversationsConversationsResultsFilterOrWorkflows,
    QueryConversationsConversationsResultsFilterWorkflows,
    QueryConversationsConversationsResultsMessages,
    QueryConversationsConversationsResultsMessagesCitations,
    QueryConversationsConversationsResultsMessagesCitationsContent,
    QueryConversationsConversationsResultsMessagesCitationsContentAudio,
    QueryConversationsConversationsResultsMessagesCitationsContentDocument,
    QueryConversationsConversationsResultsMessagesCitationsContentImage,
    QueryConversationsConversationsResultsMessagesCitationsContentVideo,
    QueryConversationsConversationsResultsOwner,
    QueryConversationsConversationsResultsSpecification,
)
from .query_credits import QueryCredits, QueryCreditsCredits
from .query_events import (
    QueryEvents,
    QueryEventsEvents,
    QueryEventsEventsResults,
    QueryEventsEventsResultsAddress,
)
from .query_feeds import (
    QueryFeeds,
    QueryFeedsFeeds,
    QueryFeedsFeedsResults,
    QueryFeedsFeedsResultsDiscord,
    QueryFeedsFeedsResultsEmail,
    QueryFeedsFeedsResultsEmailGoogle,
    QueryFeedsFeedsResultsEmailMicrosoft,
    QueryFeedsFeedsResultsIssue,
    QueryFeedsFeedsResultsIssueGithub,
    QueryFeedsFeedsResultsIssueJira,
    QueryFeedsFeedsResultsIssueLinear,
    QueryFeedsFeedsResultsNotion,
    QueryFeedsFeedsResultsOwner,
    QueryFeedsFeedsResultsReddit,
    QueryFeedsFeedsResultsRss,
    QueryFeedsFeedsResultsSchedulePolicy,
    QueryFeedsFeedsResultsSearch,
    QueryFeedsFeedsResultsSite,
    QueryFeedsFeedsResultsSiteAzureBlob,
    QueryFeedsFeedsResultsSiteAzureFile,
    QueryFeedsFeedsResultsSiteGoogle,
    QueryFeedsFeedsResultsSiteGoogleDrive,
    QueryFeedsFeedsResultsSiteOneDrive,
    QueryFeedsFeedsResultsSiteS3,
    QueryFeedsFeedsResultsSiteSharePoint,
    QueryFeedsFeedsResultsSlack,
    QueryFeedsFeedsResultsWeb,
    QueryFeedsFeedsResultsWorkflow,
    QueryFeedsFeedsResultsYoutube,
)
from .query_labels import QueryLabels, QueryLabelsLabels, QueryLabelsLabelsResults
from .query_medical_conditions import (
    QueryMedicalConditions,
    QueryMedicalConditionsMedicalConditions,
    QueryMedicalConditionsMedicalConditionsResults,
)
from .query_medical_contraindications import (
    QueryMedicalContraindications,
    QueryMedicalContraindicationsMedicalContraindications,
    QueryMedicalContraindicationsMedicalContraindicationsResults,
)
from .query_medical_devices import (
    QueryMedicalDevices,
    QueryMedicalDevicesMedicalDevices,
    QueryMedicalDevicesMedicalDevicesResults,
)
from .query_medical_drug_classes import (
    QueryMedicalDrugClasses,
    QueryMedicalDrugClassesMedicalDrugClasses,
    QueryMedicalDrugClassesMedicalDrugClassesResults,
)
from .query_medical_drugs import (
    QueryMedicalDrugs,
    QueryMedicalDrugsMedicalDrugs,
    QueryMedicalDrugsMedicalDrugsResults,
)
from .query_medical_guidelines import (
    QueryMedicalGuidelines,
    QueryMedicalGuidelinesMedicalGuidelines,
    QueryMedicalGuidelinesMedicalGuidelinesResults,
)
from .query_medical_indications import (
    QueryMedicalIndications,
    QueryMedicalIndicationsMedicalIndications,
    QueryMedicalIndicationsMedicalIndicationsResults,
)
from .query_medical_procedures import (
    QueryMedicalProcedures,
    QueryMedicalProceduresMedicalProcedures,
    QueryMedicalProceduresMedicalProceduresResults,
)
from .query_medical_studies import (
    QueryMedicalStudies,
    QueryMedicalStudiesMedicalStudies,
    QueryMedicalStudiesMedicalStudiesResults,
    QueryMedicalStudiesMedicalStudiesResultsAddress,
)
from .query_medical_tests import (
    QueryMedicalTests,
    QueryMedicalTestsMedicalTests,
    QueryMedicalTestsMedicalTestsResults,
)
from .query_medical_therapies import (
    QueryMedicalTherapies,
    QueryMedicalTherapiesMedicalTherapies,
    QueryMedicalTherapiesMedicalTherapiesResults,
)
from .query_microsoft_teams_channels import (
    QueryMicrosoftTeamsChannels,
    QueryMicrosoftTeamsChannelsMicrosoftTeamsChannels,
    QueryMicrosoftTeamsChannelsMicrosoftTeamsChannelsResults,
)
from .query_microsoft_teams_teams import (
    QueryMicrosoftTeamsTeams,
    QueryMicrosoftTeamsTeamsMicrosoftTeamsTeams,
    QueryMicrosoftTeamsTeamsMicrosoftTeamsTeamsResults,
)
from .query_one_drive_folders import (
    QueryOneDriveFolders,
    QueryOneDriveFoldersOneDriveFolders,
    QueryOneDriveFoldersOneDriveFoldersResults,
)
from .query_organizations import (
    QueryOrganizations,
    QueryOrganizationsOrganizations,
    QueryOrganizationsOrganizationsResults,
    QueryOrganizationsOrganizationsResultsAddress,
)
from .query_persons import (
    QueryPersons,
    QueryPersonsPersons,
    QueryPersonsPersonsResults,
    QueryPersonsPersonsResultsAddress,
)
from .query_places import (
    QueryPlaces,
    QueryPlacesPlaces,
    QueryPlacesPlacesResults,
    QueryPlacesPlacesResultsAddress,
)
from .query_products import (
    QueryProducts,
    QueryProductsProducts,
    QueryProductsProductsResults,
    QueryProductsProductsResultsAddress,
)
from .query_repos import QueryRepos, QueryReposRepos, QueryReposReposResults
from .query_share_point_folders import (
    QuerySharePointFolders,
    QuerySharePointFoldersSharePointFolders,
    QuerySharePointFoldersSharePointFoldersResults,
)
from .query_share_point_libraries import (
    QuerySharePointLibraries,
    QuerySharePointLibrariesSharePointLibraries,
    QuerySharePointLibrariesSharePointLibrariesResults,
)
from .query_softwares import (
    QuerySoftwares,
    QuerySoftwaresSoftwares,
    QuerySoftwaresSoftwaresResults,
)
from .query_specifications import (
    QuerySpecifications,
    QuerySpecificationsSpecifications,
    QuerySpecificationsSpecificationsResults,
    QuerySpecificationsSpecificationsResultsAnthropic,
    QuerySpecificationsSpecificationsResultsAzureOpenAi,
    QuerySpecificationsSpecificationsResultsCohere,
    QuerySpecificationsSpecificationsResultsDeepseek,
    QuerySpecificationsSpecificationsResultsGraphStrategy,
    QuerySpecificationsSpecificationsResultsGroq,
    QuerySpecificationsSpecificationsResultsMistral,
    QuerySpecificationsSpecificationsResultsOpenAi,
    QuerySpecificationsSpecificationsResultsOwner,
    QuerySpecificationsSpecificationsResultsPromptStrategy,
    QuerySpecificationsSpecificationsResultsReplicate,
    QuerySpecificationsSpecificationsResultsRerankingStrategy,
    QuerySpecificationsSpecificationsResultsRetrievalStrategy,
    QuerySpecificationsSpecificationsResultsRevisionStrategy,
    QuerySpecificationsSpecificationsResultsStrategy,
    QuerySpecificationsSpecificationsResultsTools,
)
from .query_usage import QueryUsage, QueryUsageUsage
from .query_workflows import (
    QueryWorkflows,
    QueryWorkflowsWorkflows,
    QueryWorkflowsWorkflowsResults,
    QueryWorkflowsWorkflowsResultsActions,
    QueryWorkflowsWorkflowsResultsActionsConnector,
    QueryWorkflowsWorkflowsResultsActionsConnectorSlack,
    QueryWorkflowsWorkflowsResultsEnrichment,
    QueryWorkflowsWorkflowsResultsEnrichmentJobs,
    QueryWorkflowsWorkflowsResultsEnrichmentJobsConnector,
    QueryWorkflowsWorkflowsResultsEnrichmentJobsConnectorFhir,
    QueryWorkflowsWorkflowsResultsEnrichmentLink,
    QueryWorkflowsWorkflowsResultsExtraction,
    QueryWorkflowsWorkflowsResultsExtractionJobs,
    QueryWorkflowsWorkflowsResultsExtractionJobsConnector,
    QueryWorkflowsWorkflowsResultsExtractionJobsConnectorAzureImage,
    QueryWorkflowsWorkflowsResultsExtractionJobsConnectorAzureText,
    QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelImage,
    QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelImageSpecification,
    QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelText,
    QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelTextSpecification,
    QueryWorkflowsWorkflowsResultsExtractionJobsConnectorOpenAiImage,
    QueryWorkflowsWorkflowsResultsIndexing,
    QueryWorkflowsWorkflowsResultsIndexingJobs,
    QueryWorkflowsWorkflowsResultsIndexingJobsConnector,
    QueryWorkflowsWorkflowsResultsIngestion,
    QueryWorkflowsWorkflowsResultsIngestionCollections,
    QueryWorkflowsWorkflowsResultsIngestionIf,
    QueryWorkflowsWorkflowsResultsOwner,
    QueryWorkflowsWorkflowsResultsPreparation,
    QueryWorkflowsWorkflowsResultsPreparationJobs,
    QueryWorkflowsWorkflowsResultsPreparationJobsConnector,
    QueryWorkflowsWorkflowsResultsPreparationJobsConnectorAzureDocument,
    QueryWorkflowsWorkflowsResultsPreparationJobsConnectorDeepgram,
    QueryWorkflowsWorkflowsResultsPreparationJobsConnectorDocument,
    QueryWorkflowsWorkflowsResultsPreparationJobsConnectorEmail,
    QueryWorkflowsWorkflowsResultsPreparationJobsConnectorModelDocument,
    QueryWorkflowsWorkflowsResultsPreparationJobsConnectorModelDocumentSpecification,
    QueryWorkflowsWorkflowsResultsPreparationSummarizations,
    QueryWorkflowsWorkflowsResultsPreparationSummarizationsSpecification,
    QueryWorkflowsWorkflowsResultsStorage,
    QueryWorkflowsWorkflowsResultsStorageEmbeddings,
)
from .remove_contents_from_collection import (
    RemoveContentsFromCollection,
    RemoveContentsFromCollectionRemoveContentsFromCollection,
    RemoveContentsFromCollectionRemoveContentsFromCollectionContents,
)
from .suggest_conversation import (
    SuggestConversation,
    SuggestConversationSuggestConversation,
)
from .summarize_contents import (
    SummarizeContents,
    SummarizeContentsSummarizeContents,
    SummarizeContentsSummarizeContentsContent,
    SummarizeContentsSummarizeContentsItems,
    SummarizeContentsSummarizeContentsSpecification,
)
from .update_alert import UpdateAlert, UpdateAlertUpdateAlert
from .update_category import UpdateCategory, UpdateCategoryUpdateCategory
from .update_collection import UpdateCollection, UpdateCollectionUpdateCollection
from .update_content import (
    UpdateContent,
    UpdateContentUpdateContent,
    UpdateContentUpdateContentCollections,
)
from .update_conversation import (
    UpdateConversation,
    UpdateConversationUpdateConversation,
)
from .update_event import UpdateEvent, UpdateEventUpdateEvent
from .update_feed import UpdateFeed, UpdateFeedUpdateFeed
from .update_label import UpdateLabel, UpdateLabelUpdateLabel
from .update_medical_condition import (
    UpdateMedicalCondition,
    UpdateMedicalConditionUpdateMedicalCondition,
)
from .update_medical_contraindication import (
    UpdateMedicalContraindication,
    UpdateMedicalContraindicationUpdateMedicalContraindication,
)
from .update_medical_device import (
    UpdateMedicalDevice,
    UpdateMedicalDeviceUpdateMedicalDevice,
)
from .update_medical_drug import UpdateMedicalDrug, UpdateMedicalDrugUpdateMedicalDrug
from .update_medical_drug_class import (
    UpdateMedicalDrugClass,
    UpdateMedicalDrugClassUpdateMedicalDrugClass,
)
from .update_medical_guideline import (
    UpdateMedicalGuideline,
    UpdateMedicalGuidelineUpdateMedicalGuideline,
)
from .update_medical_indication import (
    UpdateMedicalIndication,
    UpdateMedicalIndicationUpdateMedicalIndication,
)
from .update_medical_procedure import (
    UpdateMedicalProcedure,
    UpdateMedicalProcedureUpdateMedicalProcedure,
)
from .update_medical_study import (
    UpdateMedicalStudy,
    UpdateMedicalStudyUpdateMedicalStudy,
)
from .update_medical_test import UpdateMedicalTest, UpdateMedicalTestUpdateMedicalTest
from .update_medical_therapy import (
    UpdateMedicalTherapy,
    UpdateMedicalTherapyUpdateMedicalTherapy,
)
from .update_observation import UpdateObservation, UpdateObservationUpdateObservation
from .update_organization import (
    UpdateOrganization,
    UpdateOrganizationUpdateOrganization,
)
from .update_person import UpdatePerson, UpdatePersonUpdatePerson
from .update_place import UpdatePlace, UpdatePlaceUpdatePlace
from .update_product import UpdateProduct, UpdateProductUpdateProduct
from .update_project import UpdateProject, UpdateProjectUpdateProject
from .update_repo import UpdateRepo, UpdateRepoUpdateRepo
from .update_software import UpdateSoftware, UpdateSoftwareUpdateSoftware
from .update_specification import (
    UpdateSpecification,
    UpdateSpecificationUpdateSpecification,
)
from .update_workflow import (
    UpdateWorkflow,
    UpdateWorkflowUpdateWorkflow,
    UpdateWorkflowUpdateWorkflowActions,
    UpdateWorkflowUpdateWorkflowActionsConnector,
    UpdateWorkflowUpdateWorkflowActionsConnectorSlack,
    UpdateWorkflowUpdateWorkflowEnrichment,
    UpdateWorkflowUpdateWorkflowEnrichmentJobs,
    UpdateWorkflowUpdateWorkflowEnrichmentJobsConnector,
    UpdateWorkflowUpdateWorkflowEnrichmentJobsConnectorFhir,
    UpdateWorkflowUpdateWorkflowEnrichmentLink,
    UpdateWorkflowUpdateWorkflowExtraction,
    UpdateWorkflowUpdateWorkflowExtractionJobs,
    UpdateWorkflowUpdateWorkflowExtractionJobsConnector,
    UpdateWorkflowUpdateWorkflowExtractionJobsConnectorAzureImage,
    UpdateWorkflowUpdateWorkflowExtractionJobsConnectorAzureText,
    UpdateWorkflowUpdateWorkflowExtractionJobsConnectorModelImage,
    UpdateWorkflowUpdateWorkflowExtractionJobsConnectorModelImageSpecification,
    UpdateWorkflowUpdateWorkflowExtractionJobsConnectorModelText,
    UpdateWorkflowUpdateWorkflowExtractionJobsConnectorModelTextSpecification,
    UpdateWorkflowUpdateWorkflowExtractionJobsConnectorOpenAiImage,
    UpdateWorkflowUpdateWorkflowIndexing,
    UpdateWorkflowUpdateWorkflowIndexingJobs,
    UpdateWorkflowUpdateWorkflowIndexingJobsConnector,
    UpdateWorkflowUpdateWorkflowIngestion,
    UpdateWorkflowUpdateWorkflowIngestionCollections,
    UpdateWorkflowUpdateWorkflowIngestionIf,
    UpdateWorkflowUpdateWorkflowPreparation,
    UpdateWorkflowUpdateWorkflowPreparationJobs,
    UpdateWorkflowUpdateWorkflowPreparationJobsConnector,
    UpdateWorkflowUpdateWorkflowPreparationJobsConnectorAzureDocument,
    UpdateWorkflowUpdateWorkflowPreparationJobsConnectorDeepgram,
    UpdateWorkflowUpdateWorkflowPreparationJobsConnectorDocument,
    UpdateWorkflowUpdateWorkflowPreparationJobsConnectorEmail,
    UpdateWorkflowUpdateWorkflowPreparationJobsConnectorModelDocument,
    UpdateWorkflowUpdateWorkflowPreparationJobsConnectorModelDocumentSpecification,
    UpdateWorkflowUpdateWorkflowPreparationSummarizations,
    UpdateWorkflowUpdateWorkflowPreparationSummarizationsSpecification,
    UpdateWorkflowUpdateWorkflowStorage,
    UpdateWorkflowUpdateWorkflowStorageEmbeddings,
)

__all__ = [
    "ADD_CONTENTS_TO_COLLECTIONS_GQL",
    "AddContentsToCollections",
    "AddContentsToCollectionsAddContentsToCollections",
    "AddContentsToCollectionsAddContentsToCollectionsContents",
    "AddressFilter",
    "AddressInput",
    "AlertFilter",
    "AlertInput",
    "AlertSchedulePolicyInput",
    "AlertTypes",
    "AlertUpdateInput",
    "AmazonFeedPropertiesInput",
    "AmazonFeedPropertiesUpdateInput",
    "AnthropicModelPropertiesInput",
    "AnthropicModelPropertiesUpdateInput",
    "AnthropicModels",
    "ApplyPolicy",
    "AsyncBaseClient",
    "AtlassianJiraFeedPropertiesInput",
    "AtlassianJiraFeedPropertiesUpdateInput",
    "AudioMetadataInput",
    "AzureBlobFeedPropertiesInput",
    "AzureBlobFeedPropertiesUpdateInput",
    "AzureDocumentIntelligenceModels",
    "AzureDocumentIntelligenceVersions",
    "AzureDocumentPreparationPropertiesInput",
    "AzureFileFeedPropertiesInput",
    "AzureFileFeedPropertiesUpdateInput",
    "AzureImageExtractionPropertiesInput",
    "AzureOpenAIModelPropertiesInput",
    "AzureOpenAIModelPropertiesUpdateInput",
    "AzureOpenAIModels",
    "AzureTextExtractionPropertiesInput",
    "BaseModel",
    "BillableMetrics",
    "BoundingBoxInput",
    "CLEAR_CONVERSATION_GQL",
    "CLOSE_CONVERSATION_GQL",
    "COUNT_ALERTS_GQL",
    "COUNT_CATEGORIES_GQL",
    "COUNT_COLLECTIONS_GQL",
    "COUNT_CONTENTS_GQL",
    "COUNT_CONVERSATIONS_GQL",
    "COUNT_EVENTS_GQL",
    "COUNT_FEEDS_GQL",
    "COUNT_LABELS_GQL",
    "COUNT_MEDICAL_CONDITIONS_GQL",
    "COUNT_MEDICAL_CONTRAINDICATIONS_GQL",
    "COUNT_MEDICAL_DEVICES_GQL",
    "COUNT_MEDICAL_DRUGS_GQL",
    "COUNT_MEDICAL_DRUG_CLASSES_GQL",
    "COUNT_MEDICAL_GUIDELINES_GQL",
    "COUNT_MEDICAL_INDICATIONS_GQL",
    "COUNT_MEDICAL_PROCEDURES_GQL",
    "COUNT_MEDICAL_STUDIES_GQL",
    "COUNT_MEDICAL_TESTS_GQL",
    "COUNT_MEDICAL_THERAPIES_GQL",
    "COUNT_ORGANIZATIONS_GQL",
    "COUNT_PERSONS_GQL",
    "COUNT_PLACES_GQL",
    "COUNT_PRODUCTS_GQL",
    "COUNT_REPOS_GQL",
    "COUNT_SOFTWARES_GQL",
    "COUNT_SPECIFICATIONS_GQL",
    "COUNT_WORKFLOWS_GQL",
    "CREATE_ALERT_GQL",
    "CREATE_CATEGORY_GQL",
    "CREATE_COLLECTION_GQL",
    "CREATE_CONVERSATION_GQL",
    "CREATE_EVENT_GQL",
    "CREATE_FEED_GQL",
    "CREATE_LABEL_GQL",
    "CREATE_MEDICAL_CONDITION_GQL",
    "CREATE_MEDICAL_CONTRAINDICATION_GQL",
    "CREATE_MEDICAL_DEVICE_GQL",
    "CREATE_MEDICAL_DRUG_CLASS_GQL",
    "CREATE_MEDICAL_DRUG_GQL",
    "CREATE_MEDICAL_GUIDELINE_GQL",
    "CREATE_MEDICAL_INDICATION_GQL",
    "CREATE_MEDICAL_PROCEDURE_GQL",
    "CREATE_MEDICAL_STUDY_GQL",
    "CREATE_MEDICAL_TEST_GQL",
    "CREATE_MEDICAL_THERAPY_GQL",
    "CREATE_OBSERVATION_GQL",
    "CREATE_ORGANIZATION_GQL",
    "CREATE_PERSON_GQL",
    "CREATE_PLACE_GQL",
    "CREATE_PRODUCT_GQL",
    "CREATE_REPO_GQL",
    "CREATE_SOFTWARE_GQL",
    "CREATE_SPECIFICATION_GQL",
    "CREATE_WORKFLOW_GQL",
    "CategoryFacetInput",
    "CategoryFacetTypes",
    "CategoryFilter",
    "CategoryInput",
    "CategoryUpdateInput",
    "ClearConversation",
    "ClearConversationClearConversation",
    "Client",
    "CloseConversation",
    "CloseConversationCloseConversation",
    "CohereModelPropertiesInput",
    "CohereModelPropertiesUpdateInput",
    "CohereModels",
    "CollectionFilter",
    "CollectionInput",
    "CollectionTypes",
    "CollectionUpdateInput",
    "ContentCriteriaInput",
    "ContentCriteriaLevelInput",
    "ContentFacetInput",
    "ContentFacetTypes",
    "ContentFilter",
    "ContentFilterLevel",
    "ContentGraphInput",
    "ContentIndexingConnectorInput",
    "ContentIndexingServiceTypes",
    "ContentInput",
    "ContentPublishingConnectorInput",
    "ContentPublishingConnectorUpdateInput",
    "ContentPublishingFormats",
    "ContentPublishingServiceTypes",
    "ContentTypes",
    "ContentUpdateInput",
    "ConversationFilter",
    "ConversationInput",
    "ConversationRoleTypes",
    "ConversationSearchTypes",
    "ConversationStrategyInput",
    "ConversationStrategyTypes",
    "ConversationStrategyUpdateInput",
    "ConversationTypes",
    "ConversationUpdateInput",
    "CountAlerts",
    "CountAlertsCountAlerts",
    "CountCategories",
    "CountCategoriesCountCategories",
    "CountCollections",
    "CountCollectionsCountCollections",
    "CountContents",
    "CountContentsCountContents",
    "CountConversations",
    "CountConversationsCountConversations",
    "CountEvents",
    "CountEventsCountEvents",
    "CountFeeds",
    "CountFeedsCountFeeds",
    "CountLabels",
    "CountLabelsCountLabels",
    "CountMedicalConditions",
    "CountMedicalConditionsCountMedicalConditions",
    "CountMedicalContraindications",
    "CountMedicalContraindicationsCountMedicalContraindications",
    "CountMedicalDevices",
    "CountMedicalDevicesCountMedicalDevices",
    "CountMedicalDrugClasses",
    "CountMedicalDrugClassesCountMedicalDrugClasses",
    "CountMedicalDrugs",
    "CountMedicalDrugsCountMedicalDrugs",
    "CountMedicalGuidelines",
    "CountMedicalGuidelinesCountMedicalGuidelines",
    "CountMedicalIndications",
    "CountMedicalIndicationsCountMedicalIndications",
    "CountMedicalProcedures",
    "CountMedicalProceduresCountMedicalProcedures",
    "CountMedicalStudies",
    "CountMedicalStudiesCountMedicalStudies",
    "CountMedicalTests",
    "CountMedicalTestsCountMedicalTests",
    "CountMedicalTherapies",
    "CountMedicalTherapiesCountMedicalTherapies",
    "CountOrganizations",
    "CountOrganizationsCountOrganizations",
    "CountPersons",
    "CountPersonsCountPersons",
    "CountPlaces",
    "CountPlacesCountPlaces",
    "CountProducts",
    "CountProductsCountProducts",
    "CountRepos",
    "CountReposCountRepos",
    "CountSoftwares",
    "CountSoftwaresCountSoftwares",
    "CountSpecifications",
    "CountSpecificationsCountSpecifications",
    "CountWorkflows",
    "CountWorkflowsCountWorkflows",
    "CreateAlert",
    "CreateAlertCreateAlert",
    "CreateCategory",
    "CreateCategoryCreateCategory",
    "CreateCollection",
    "CreateCollectionCreateCollection",
    "CreateConversation",
    "CreateConversationCreateConversation",
    "CreateEvent",
    "CreateEventCreateEvent",
    "CreateFeed",
    "CreateFeedCreateFeed",
    "CreateLabel",
    "CreateLabelCreateLabel",
    "CreateMedicalCondition",
    "CreateMedicalConditionCreateMedicalCondition",
    "CreateMedicalContraindication",
    "CreateMedicalContraindicationCreateMedicalContraindication",
    "CreateMedicalDevice",
    "CreateMedicalDeviceCreateMedicalDevice",
    "CreateMedicalDrug",
    "CreateMedicalDrugClass",
    "CreateMedicalDrugClassCreateMedicalDrugClass",
    "CreateMedicalDrugCreateMedicalDrug",
    "CreateMedicalGuideline",
    "CreateMedicalGuidelineCreateMedicalGuideline",
    "CreateMedicalIndication",
    "CreateMedicalIndicationCreateMedicalIndication",
    "CreateMedicalProcedure",
    "CreateMedicalProcedureCreateMedicalProcedure",
    "CreateMedicalStudy",
    "CreateMedicalStudyCreateMedicalStudy",
    "CreateMedicalTest",
    "CreateMedicalTestCreateMedicalTest",
    "CreateMedicalTherapy",
    "CreateMedicalTherapyCreateMedicalTherapy",
    "CreateObservation",
    "CreateObservationCreateObservation",
    "CreateOrganization",
    "CreateOrganizationCreateOrganization",
    "CreatePerson",
    "CreatePersonCreatePerson",
    "CreatePlace",
    "CreatePlaceCreatePlace",
    "CreateProduct",
    "CreateProductCreateProduct",
    "CreateRepo",
    "CreateRepoCreateRepo",
    "CreateSoftware",
    "CreateSoftwareCreateSoftware",
    "CreateSpecification",
    "CreateSpecificationCreateSpecification",
    "CreateWorkflow",
    "CreateWorkflowCreateWorkflow",
    "CreateWorkflowCreateWorkflowActions",
    "CreateWorkflowCreateWorkflowActionsConnector",
    "CreateWorkflowCreateWorkflowActionsConnectorSlack",
    "CreateWorkflowCreateWorkflowEnrichment",
    "CreateWorkflowCreateWorkflowEnrichmentJobs",
    "CreateWorkflowCreateWorkflowEnrichmentJobsConnector",
    "CreateWorkflowCreateWorkflowEnrichmentJobsConnectorFhir",
    "CreateWorkflowCreateWorkflowEnrichmentLink",
    "CreateWorkflowCreateWorkflowExtraction",
    "CreateWorkflowCreateWorkflowExtractionJobs",
    "CreateWorkflowCreateWorkflowExtractionJobsConnector",
    "CreateWorkflowCreateWorkflowExtractionJobsConnectorAzureImage",
    "CreateWorkflowCreateWorkflowExtractionJobsConnectorAzureText",
    "CreateWorkflowCreateWorkflowExtractionJobsConnectorModelImage",
    "CreateWorkflowCreateWorkflowExtractionJobsConnectorModelImageSpecification",
    "CreateWorkflowCreateWorkflowExtractionJobsConnectorModelText",
    "CreateWorkflowCreateWorkflowExtractionJobsConnectorModelTextSpecification",
    "CreateWorkflowCreateWorkflowExtractionJobsConnectorOpenAiImage",
    "CreateWorkflowCreateWorkflowIndexing",
    "CreateWorkflowCreateWorkflowIndexingJobs",
    "CreateWorkflowCreateWorkflowIndexingJobsConnector",
    "CreateWorkflowCreateWorkflowIngestion",
    "CreateWorkflowCreateWorkflowIngestionCollections",
    "CreateWorkflowCreateWorkflowIngestionIf",
    "CreateWorkflowCreateWorkflowPreparation",
    "CreateWorkflowCreateWorkflowPreparationJobs",
    "CreateWorkflowCreateWorkflowPreparationJobsConnector",
    "CreateWorkflowCreateWorkflowPreparationJobsConnectorAzureDocument",
    "CreateWorkflowCreateWorkflowPreparationJobsConnectorDeepgram",
    "CreateWorkflowCreateWorkflowPreparationJobsConnectorDocument",
    "CreateWorkflowCreateWorkflowPreparationJobsConnectorEmail",
    "CreateWorkflowCreateWorkflowPreparationJobsConnectorModelDocument",
    "CreateWorkflowCreateWorkflowPreparationJobsConnectorModelDocumentSpecification",
    "CreateWorkflowCreateWorkflowPreparationSummarizations",
    "CreateWorkflowCreateWorkflowPreparationSummarizationsSpecification",
    "CreateWorkflowCreateWorkflowStorage",
    "CreateWorkflowCreateWorkflowStorageEmbeddings",
    "DELETE_ALERTS_GQL",
    "DELETE_ALERT_GQL",
    "DELETE_ALL_ALERTS_GQL",
    "DELETE_ALL_CATEGORIES_GQL",
    "DELETE_ALL_COLLECTIONS_GQL",
    "DELETE_ALL_CONTENTS_GQL",
    "DELETE_ALL_CONVERSATIONS_GQL",
    "DELETE_ALL_EVENTS_GQL",
    "DELETE_ALL_FEEDS_GQL",
    "DELETE_ALL_LABELS_GQL",
    "DELETE_ALL_MEDICAL_CONDITIONS_GQL",
    "DELETE_ALL_MEDICAL_CONTRAINDICATIONS_GQL",
    "DELETE_ALL_MEDICAL_DEVICES_GQL",
    "DELETE_ALL_MEDICAL_DRUGS_GQL",
    "DELETE_ALL_MEDICAL_DRUG_CLASSES_GQL",
    "DELETE_ALL_MEDICAL_GUIDELINES_GQL",
    "DELETE_ALL_MEDICAL_INDICATIONS_GQL",
    "DELETE_ALL_MEDICAL_PROCEDURES_GQL",
    "DELETE_ALL_MEDICAL_STUDIES_GQL",
    "DELETE_ALL_MEDICAL_TESTS_GQL",
    "DELETE_ALL_MEDICAL_THERAPIES_GQL",
    "DELETE_ALL_ORGANIZATIONS_GQL",
    "DELETE_ALL_PERSONS_GQL",
    "DELETE_ALL_PLACES_GQL",
    "DELETE_ALL_PRODUCTS_GQL",
    "DELETE_ALL_REPOS_GQL",
    "DELETE_ALL_SOFTWARES_GQL",
    "DELETE_ALL_SPECIFICATIONS_GQL",
    "DELETE_ALL_WORKFLOWS_GQL",
    "DELETE_CATEGORIES_GQL",
    "DELETE_CATEGORY_GQL",
    "DELETE_COLLECTIONS_GQL",
    "DELETE_COLLECTION_GQL",
    "DELETE_CONTENTS_GQL",
    "DELETE_CONTENT_GQL",
    "DELETE_CONVERSATIONS_GQL",
    "DELETE_CONVERSATION_GQL",
    "DELETE_EVENTS_GQL",
    "DELETE_EVENT_GQL",
    "DELETE_FEEDS_GQL",
    "DELETE_FEED_GQL",
    "DELETE_LABELS_GQL",
    "DELETE_LABEL_GQL",
    "DELETE_MEDICAL_CONDITIONS_GQL",
    "DELETE_MEDICAL_CONDITION_GQL",
    "DELETE_MEDICAL_CONTRAINDICATIONS_GQL",
    "DELETE_MEDICAL_CONTRAINDICATION_GQL",
    "DELETE_MEDICAL_DEVICES_GQL",
    "DELETE_MEDICAL_DEVICE_GQL",
    "DELETE_MEDICAL_DRUGS_GQL",
    "DELETE_MEDICAL_DRUG_CLASSES_GQL",
    "DELETE_MEDICAL_DRUG_CLASS_GQL",
    "DELETE_MEDICAL_DRUG_GQL",
    "DELETE_MEDICAL_GUIDELINES_GQL",
    "DELETE_MEDICAL_GUIDELINE_GQL",
    "DELETE_MEDICAL_INDICATIONS_GQL",
    "DELETE_MEDICAL_INDICATION_GQL",
    "DELETE_MEDICAL_PROCEDURES_GQL",
    "DELETE_MEDICAL_PROCEDURE_GQL",
    "DELETE_MEDICAL_STUDIES_GQL",
    "DELETE_MEDICAL_STUDY_GQL",
    "DELETE_MEDICAL_TESTS_GQL",
    "DELETE_MEDICAL_TEST_GQL",
    "DELETE_MEDICAL_THERAPIES_GQL",
    "DELETE_MEDICAL_THERAPY_GQL",
    "DELETE_OBSERVATION_GQL",
    "DELETE_ORGANIZATIONS_GQL",
    "DELETE_ORGANIZATION_GQL",
    "DELETE_PERSONS_GQL",
    "DELETE_PERSON_GQL",
    "DELETE_PLACES_GQL",
    "DELETE_PLACE_GQL",
    "DELETE_PRODUCTS_GQL",
    "DELETE_PRODUCT_GQL",
    "DELETE_REPOS_GQL",
    "DELETE_REPO_GQL",
    "DELETE_SOFTWARES_GQL",
    "DELETE_SOFTWARE_GQL",
    "DELETE_SPECIFICATIONS_GQL",
    "DELETE_SPECIFICATION_GQL",
    "DELETE_WORKFLOWS_GQL",
    "DELETE_WORKFLOW_GQL",
    "DISABLE_ALERT_GQL",
    "DISABLE_FEED_GQL",
    "DateRangeFilter",
    "DateRangeInput",
    "DeepgramAudioPreparationPropertiesInput",
    "DeepgramModels",
    "DeepseekModelPropertiesInput",
    "DeepseekModelPropertiesUpdateInput",
    "DeepseekModels",
    "DeleteAlert",
    "DeleteAlertDeleteAlert",
    "DeleteAlerts",
    "DeleteAlertsDeleteAlerts",
    "DeleteAllAlerts",
    "DeleteAllAlertsDeleteAllAlerts",
    "DeleteAllCategories",
    "DeleteAllCategoriesDeleteAllCategories",
    "DeleteAllCollections",
    "DeleteAllCollectionsDeleteAllCollections",
    "DeleteAllContents",
    "DeleteAllContentsDeleteAllContents",
    "DeleteAllConversations",
    "DeleteAllConversationsDeleteAllConversations",
    "DeleteAllEvents",
    "DeleteAllEventsDeleteAllEvents",
    "DeleteAllFeeds",
    "DeleteAllFeedsDeleteAllFeeds",
    "DeleteAllLabels",
    "DeleteAllLabelsDeleteAllLabels",
    "DeleteAllMedicalConditions",
    "DeleteAllMedicalConditionsDeleteAllMedicalConditions",
    "DeleteAllMedicalContraindications",
    "DeleteAllMedicalContraindicationsDeleteAllMedicalContraindications",
    "DeleteAllMedicalDevices",
    "DeleteAllMedicalDevicesDeleteAllMedicalDevices",
    "DeleteAllMedicalDrugClasses",
    "DeleteAllMedicalDrugClassesDeleteAllMedicalDrugClasses",
    "DeleteAllMedicalDrugs",
    "DeleteAllMedicalDrugsDeleteAllMedicalDrugs",
    "DeleteAllMedicalGuidelines",
    "DeleteAllMedicalGuidelinesDeleteAllMedicalGuidelines",
    "DeleteAllMedicalIndications",
    "DeleteAllMedicalIndicationsDeleteAllMedicalIndications",
    "DeleteAllMedicalProcedures",
    "DeleteAllMedicalProceduresDeleteAllMedicalProcedures",
    "DeleteAllMedicalStudies",
    "DeleteAllMedicalStudiesDeleteAllMedicalStudies",
    "DeleteAllMedicalTests",
    "DeleteAllMedicalTestsDeleteAllMedicalTests",
    "DeleteAllMedicalTherapies",
    "DeleteAllMedicalTherapiesDeleteAllMedicalTherapies",
    "DeleteAllOrganizations",
    "DeleteAllOrganizationsDeleteAllOrganizations",
    "DeleteAllPersons",
    "DeleteAllPersonsDeleteAllPersons",
    "DeleteAllPlaces",
    "DeleteAllPlacesDeleteAllPlaces",
    "DeleteAllProducts",
    "DeleteAllProductsDeleteAllProducts",
    "DeleteAllRepos",
    "DeleteAllReposDeleteAllRepos",
    "DeleteAllSoftwares",
    "DeleteAllSoftwaresDeleteAllSoftwares",
    "DeleteAllSpecifications",
    "DeleteAllSpecificationsDeleteAllSpecifications",
    "DeleteAllWorkflows",
    "DeleteAllWorkflowsDeleteAllWorkflows",
    "DeleteCategories",
    "DeleteCategoriesDeleteCategories",
    "DeleteCategory",
    "DeleteCategoryDeleteCategory",
    "DeleteCollection",
    "DeleteCollectionDeleteCollection",
    "DeleteCollections",
    "DeleteCollectionsDeleteCollections",
    "DeleteContent",
    "DeleteContentDeleteContent",
    "DeleteContents",
    "DeleteContentsDeleteContents",
    "DeleteConversation",
    "DeleteConversationDeleteConversation",
    "DeleteConversations",
    "DeleteConversationsDeleteConversations",
    "DeleteEvent",
    "DeleteEventDeleteEvent",
    "DeleteEvents",
    "DeleteEventsDeleteEvents",
    "DeleteFeed",
    "DeleteFeedDeleteFeed",
    "DeleteFeeds",
    "DeleteFeedsDeleteFeeds",
    "DeleteLabel",
    "DeleteLabelDeleteLabel",
    "DeleteLabels",
    "DeleteLabelsDeleteLabels",
    "DeleteMedicalCondition",
    "DeleteMedicalConditionDeleteMedicalCondition",
    "DeleteMedicalConditions",
    "DeleteMedicalConditionsDeleteMedicalConditions",
    "DeleteMedicalContraindication",
    "DeleteMedicalContraindicationDeleteMedicalContraindication",
    "DeleteMedicalContraindications",
    "DeleteMedicalContraindicationsDeleteMedicalContraindications",
    "DeleteMedicalDevice",
    "DeleteMedicalDeviceDeleteMedicalDevice",
    "DeleteMedicalDevices",
    "DeleteMedicalDevicesDeleteMedicalDevices",
    "DeleteMedicalDrug",
    "DeleteMedicalDrugClass",
    "DeleteMedicalDrugClassDeleteMedicalDrugClass",
    "DeleteMedicalDrugClasses",
    "DeleteMedicalDrugClassesDeleteMedicalDrugClasses",
    "DeleteMedicalDrugDeleteMedicalDrug",
    "DeleteMedicalDrugs",
    "DeleteMedicalDrugsDeleteMedicalDrugs",
    "DeleteMedicalGuideline",
    "DeleteMedicalGuidelineDeleteMedicalGuideline",
    "DeleteMedicalGuidelines",
    "DeleteMedicalGuidelinesDeleteMedicalGuidelines",
    "DeleteMedicalIndication",
    "DeleteMedicalIndicationDeleteMedicalIndication",
    "DeleteMedicalIndications",
    "DeleteMedicalIndicationsDeleteMedicalIndications",
    "DeleteMedicalProcedure",
    "DeleteMedicalProcedureDeleteMedicalProcedure",
    "DeleteMedicalProcedures",
    "DeleteMedicalProceduresDeleteMedicalProcedures",
    "DeleteMedicalStudies",
    "DeleteMedicalStudiesDeleteMedicalStudies",
    "DeleteMedicalStudy",
    "DeleteMedicalStudyDeleteMedicalStudy",
    "DeleteMedicalTest",
    "DeleteMedicalTestDeleteMedicalTest",
    "DeleteMedicalTests",
    "DeleteMedicalTestsDeleteMedicalTests",
    "DeleteMedicalTherapies",
    "DeleteMedicalTherapiesDeleteMedicalTherapies",
    "DeleteMedicalTherapy",
    "DeleteMedicalTherapyDeleteMedicalTherapy",
    "DeleteObservation",
    "DeleteObservationDeleteObservation",
    "DeleteOrganization",
    "DeleteOrganizationDeleteOrganization",
    "DeleteOrganizations",
    "DeleteOrganizationsDeleteOrganizations",
    "DeletePerson",
    "DeletePersonDeletePerson",
    "DeletePersons",
    "DeletePersonsDeletePersons",
    "DeletePlace",
    "DeletePlaceDeletePlace",
    "DeletePlaces",
    "DeletePlacesDeletePlaces",
    "DeleteProduct",
    "DeleteProductDeleteProduct",
    "DeleteProducts",
    "DeleteProductsDeleteProducts",
    "DeleteRepo",
    "DeleteRepoDeleteRepo",
    "DeleteRepos",
    "DeleteReposDeleteRepos",
    "DeleteSoftware",
    "DeleteSoftwareDeleteSoftware",
    "DeleteSoftwares",
    "DeleteSoftwaresDeleteSoftwares",
    "DeleteSpecification",
    "DeleteSpecificationDeleteSpecification",
    "DeleteSpecifications",
    "DeleteSpecificationsDeleteSpecifications",
    "DeleteWorkflow",
    "DeleteWorkflowDeleteWorkflow",
    "DeleteWorkflows",
    "DeleteWorkflowsDeleteWorkflows",
    "DeviceTypes",
    "DisableAlert",
    "DisableAlertDisableAlert",
    "DisableFeed",
    "DisableFeedDisableFeed",
    "DiscordFeedPropertiesInput",
    "DiscordFeedPropertiesUpdateInput",
    "DocumentMetadataInput",
    "DocumentPreparationPropertiesInput",
    "DrawingMetadataInput",
    "ENABLE_ALERT_GQL",
    "ENABLE_FEED_GQL",
    "EXTRACT_CONTENTS_GQL",
    "ElevenLabsModels",
    "ElevenLabsPublishingPropertiesInput",
    "EmailFeedPropertiesInput",
    "EmailFeedPropertiesUpdateInput",
    "EmailListingTypes",
    "EmailMetadataInput",
    "EmailPreparationPropertiesInput",
    "EmbeddingsStrategyInput",
    "EnableAlert",
    "EnableAlertEnableAlert",
    "EnableFeed",
    "EnableFeedEnableFeed",
    "EnrichmentWorkflowJobInput",
    "EnrichmentWorkflowStageInput",
    "EntityEnrichmentConnectorInput",
    "EntityEnrichmentServiceTypes",
    "EntityExtractionConnectorInput",
    "EntityExtractionServiceTypes",
    "EntityReferenceFilter",
    "EntityReferenceInput",
    "EntityState",
    "EntityTypes",
    "EnvironmentTypes",
    "EventFacetInput",
    "EventFacetTypes",
    "EventFilter",
    "EventInput",
    "EventUpdateInput",
    "ExtractContents",
    "ExtractContentsExtractContents",
    "ExtractContentsExtractContentsContent",
    "ExtractContentsExtractContentsSpecification",
    "ExtractionWorkflowJobInput",
    "ExtractionWorkflowStageInput",
    "FHIREnrichmentPropertiesInput",
    "FacetValueTypes",
    "FeedConnectorTypes",
    "FeedFilter",
    "FeedInput",
    "FeedListingTypes",
    "FeedSchedulePolicyInput",
    "FeedServiceTypes",
    "FeedTypes",
    "FeedUpdateInput",
    "FilePreparationConnectorInput",
    "FilePreparationServiceTypes",
    "FileTypes",
    "GET_ALERT_GQL",
    "GET_CATEGORY_GQL",
    "GET_COLLECTION_GQL",
    "GET_CONTENT_GQL",
    "GET_CONVERSATION_GQL",
    "GET_EVENT_GQL",
    "GET_FEED_GQL",
    "GET_LABEL_GQL",
    "GET_MEDICAL_CONDITION_GQL",
    "GET_MEDICAL_CONTRAINDICATION_GQL",
    "GET_MEDICAL_DEVICE_GQL",
    "GET_MEDICAL_DRUG_CLASS_GQL",
    "GET_MEDICAL_DRUG_GQL",
    "GET_MEDICAL_GUIDELINE_GQL",
    "GET_MEDICAL_INDICATION_GQL",
    "GET_MEDICAL_PROCEDURE_GQL",
    "GET_MEDICAL_STUDY_GQL",
    "GET_MEDICAL_TEST_GQL",
    "GET_MEDICAL_THERAPY_GQL",
    "GET_ORGANIZATION_GQL",
    "GET_PERSON_GQL",
    "GET_PLACE_GQL",
    "GET_PRODUCT_GQL",
    "GET_PROJECT_GQL",
    "GET_REPO_GQL",
    "GET_SHARE_POINT_CONSENT_URI_GQL",
    "GET_SOFTWARE_GQL",
    "GET_SPECIFICATION_GQL",
    "GET_WORKFLOW_GQL",
    "GeometryMetadataInput",
    "GetAlert",
    "GetAlertAlert",
    "GetAlertAlertFilter",
    "GetAlertAlertFilterAnd",
    "GetAlertAlertFilterAndCollections",
    "GetAlertAlertFilterAndFeeds",
    "GetAlertAlertFilterAndObservations",
    "GetAlertAlertFilterAndObservationsObservable",
    "GetAlertAlertFilterAndWorkflows",
    "GetAlertAlertFilterCollections",
    "GetAlertAlertFilterContents",
    "GetAlertAlertFilterCreationDateRange",
    "GetAlertAlertFilterDateRange",
    "GetAlertAlertFilterFeeds",
    "GetAlertAlertFilterObservations",
    "GetAlertAlertFilterObservationsObservable",
    "GetAlertAlertFilterOr",
    "GetAlertAlertFilterOrCollections",
    "GetAlertAlertFilterOrFeeds",
    "GetAlertAlertFilterOrObservations",
    "GetAlertAlertFilterOrObservationsObservable",
    "GetAlertAlertFilterOrWorkflows",
    "GetAlertAlertFilterWorkflows",
    "GetAlertAlertIntegration",
    "GetAlertAlertIntegrationSlack",
    "GetAlertAlertOwner",
    "GetAlertAlertPublishSpecification",
    "GetAlertAlertPublishing",
    "GetAlertAlertPublishingElevenLabs",
    "GetAlertAlertSummarySpecification",
    "GetCategory",
    "GetCategoryCategory",
    "GetCollection",
    "GetCollectionCollection",
    "GetCollectionCollectionContents",
    "GetCollectionCollectionOwner",
    "GetContent",
    "GetContentContent",
    "GetContentContentAddress",
    "GetContentContentAudio",
    "GetContentContentChildren",
    "GetContentContentCollections",
    "GetContentContentDocument",
    "GetContentContentEmail",
    "GetContentContentEmailBcc",
    "GetContentContentEmailCc",
    "GetContentContentEmailFrom",
    "GetContentContentEmailTo",
    "GetContentContentFeed",
    "GetContentContentImage",
    "GetContentContentIssue",
    "GetContentContentLanguage",
    "GetContentContentLinks",
    "GetContentContentLocation",
    "GetContentContentObservations",
    "GetContentContentObservationsObservable",
    "GetContentContentObservationsOccurrences",
    "GetContentContentObservationsOccurrencesBoundingBox",
    "GetContentContentObservationsRelated",
    "GetContentContentOwner",
    "GetContentContentPackage",
    "GetContentContentPages",
    "GetContentContentPagesChunks",
    "GetContentContentParent",
    "GetContentContentSegments",
    "GetContentContentVideo",
    "GetContentContentWorkflow",
    "GetConversation",
    "GetConversationConversation",
    "GetConversationConversationAugmentedFilter",
    "GetConversationConversationAugmentedFilterAnd",
    "GetConversationConversationAugmentedFilterAndCollections",
    "GetConversationConversationAugmentedFilterAndFeeds",
    "GetConversationConversationAugmentedFilterAndObservations",
    "GetConversationConversationAugmentedFilterAndObservationsObservable",
    "GetConversationConversationAugmentedFilterAndWorkflows",
    "GetConversationConversationAugmentedFilterCollections",
    "GetConversationConversationAugmentedFilterContents",
    "GetConversationConversationAugmentedFilterCreationDateRange",
    "GetConversationConversationAugmentedFilterDateRange",
    "GetConversationConversationAugmentedFilterFeeds",
    "GetConversationConversationAugmentedFilterObservations",
    "GetConversationConversationAugmentedFilterObservationsObservable",
    "GetConversationConversationAugmentedFilterOr",
    "GetConversationConversationAugmentedFilterOrCollections",
    "GetConversationConversationAugmentedFilterOrFeeds",
    "GetConversationConversationAugmentedFilterOrObservations",
    "GetConversationConversationAugmentedFilterOrObservationsObservable",
    "GetConversationConversationAugmentedFilterOrWorkflows",
    "GetConversationConversationAugmentedFilterWorkflows",
    "GetConversationConversationFilter",
    "GetConversationConversationFilterAnd",
    "GetConversationConversationFilterAndCollections",
    "GetConversationConversationFilterAndFeeds",
    "GetConversationConversationFilterAndObservations",
    "GetConversationConversationFilterAndObservationsObservable",
    "GetConversationConversationFilterAndWorkflows",
    "GetConversationConversationFilterCollections",
    "GetConversationConversationFilterContents",
    "GetConversationConversationFilterCreationDateRange",
    "GetConversationConversationFilterDateRange",
    "GetConversationConversationFilterFeeds",
    "GetConversationConversationFilterObservations",
    "GetConversationConversationFilterObservationsObservable",
    "GetConversationConversationFilterOr",
    "GetConversationConversationFilterOrCollections",
    "GetConversationConversationFilterOrFeeds",
    "GetConversationConversationFilterOrObservations",
    "GetConversationConversationFilterOrObservationsObservable",
    "GetConversationConversationFilterOrWorkflows",
    "GetConversationConversationFilterWorkflows",
    "GetConversationConversationMessages",
    "GetConversationConversationMessagesCitations",
    "GetConversationConversationMessagesCitationsContent",
    "GetConversationConversationMessagesCitationsContentAudio",
    "GetConversationConversationMessagesCitationsContentDocument",
    "GetConversationConversationMessagesCitationsContentImage",
    "GetConversationConversationMessagesCitationsContentVideo",
    "GetConversationConversationOwner",
    "GetConversationConversationSpecification",
    "GetEvent",
    "GetEventEvent",
    "GetEventEventAddress",
    "GetFeed",
    "GetFeedFeed",
    "GetFeedFeedDiscord",
    "GetFeedFeedEmail",
    "GetFeedFeedEmailGoogle",
    "GetFeedFeedEmailMicrosoft",
    "GetFeedFeedIssue",
    "GetFeedFeedIssueGithub",
    "GetFeedFeedIssueJira",
    "GetFeedFeedIssueLinear",
    "GetFeedFeedNotion",
    "GetFeedFeedOwner",
    "GetFeedFeedReddit",
    "GetFeedFeedRss",
    "GetFeedFeedSchedulePolicy",
    "GetFeedFeedSearch",
    "GetFeedFeedSite",
    "GetFeedFeedSiteAzureBlob",
    "GetFeedFeedSiteAzureFile",
    "GetFeedFeedSiteGoogle",
    "GetFeedFeedSiteGoogleDrive",
    "GetFeedFeedSiteOneDrive",
    "GetFeedFeedSiteS3",
    "GetFeedFeedSiteSharePoint",
    "GetFeedFeedSlack",
    "GetFeedFeedWeb",
    "GetFeedFeedWorkflow",
    "GetFeedFeedYoutube",
    "GetLabel",
    "GetLabelLabel",
    "GetMedicalCondition",
    "GetMedicalConditionMedicalCondition",
    "GetMedicalContraindication",
    "GetMedicalContraindicationMedicalContraindication",
    "GetMedicalDevice",
    "GetMedicalDeviceMedicalDevice",
    "GetMedicalDrug",
    "GetMedicalDrugClass",
    "GetMedicalDrugClassMedicalDrugClass",
    "GetMedicalDrugMedicalDrug",
    "GetMedicalGuideline",
    "GetMedicalGuidelineMedicalGuideline",
    "GetMedicalIndication",
    "GetMedicalIndicationMedicalIndication",
    "GetMedicalProcedure",
    "GetMedicalProcedureMedicalProcedure",
    "GetMedicalStudy",
    "GetMedicalStudyMedicalStudy",
    "GetMedicalStudyMedicalStudyAddress",
    "GetMedicalTest",
    "GetMedicalTestMedicalTest",
    "GetMedicalTherapy",
    "GetMedicalTherapyMedicalTherapy",
    "GetOrganization",
    "GetOrganizationOrganization",
    "GetOrganizationOrganizationAddress",
    "GetPerson",
    "GetPersonPerson",
    "GetPersonPersonAddress",
    "GetPlace",
    "GetPlacePlace",
    "GetPlacePlaceAddress",
    "GetProduct",
    "GetProductProduct",
    "GetProductProductAddress",
    "GetProject",
    "GetProjectProject",
    "GetProjectProjectQuota",
    "GetProjectProjectSpecification",
    "GetProjectProjectWorkflow",
    "GetRepo",
    "GetRepoRepo",
    "GetSharePointConsentUri",
    "GetSharePointConsentUriSharePointConsentUri",
    "GetSoftware",
    "GetSoftwareSoftware",
    "GetSpecification",
    "GetSpecificationSpecification",
    "GetSpecificationSpecificationAnthropic",
    "GetSpecificationSpecificationAzureOpenAi",
    "GetSpecificationSpecificationCohere",
    "GetSpecificationSpecificationDeepseek",
    "GetSpecificationSpecificationGraphStrategy",
    "GetSpecificationSpecificationGroq",
    "GetSpecificationSpecificationMistral",
    "GetSpecificationSpecificationOpenAi",
    "GetSpecificationSpecificationOwner",
    "GetSpecificationSpecificationPromptStrategy",
    "GetSpecificationSpecificationReplicate",
    "GetSpecificationSpecificationRerankingStrategy",
    "GetSpecificationSpecificationRetrievalStrategy",
    "GetSpecificationSpecificationRevisionStrategy",
    "GetSpecificationSpecificationStrategy",
    "GetSpecificationSpecificationTools",
    "GetWorkflow",
    "GetWorkflowWorkflow",
    "GetWorkflowWorkflowActions",
    "GetWorkflowWorkflowActionsConnector",
    "GetWorkflowWorkflowActionsConnectorSlack",
    "GetWorkflowWorkflowEnrichment",
    "GetWorkflowWorkflowEnrichmentJobs",
    "GetWorkflowWorkflowEnrichmentJobsConnector",
    "GetWorkflowWorkflowEnrichmentJobsConnectorFhir",
    "GetWorkflowWorkflowEnrichmentLink",
    "GetWorkflowWorkflowExtraction",
    "GetWorkflowWorkflowExtractionJobs",
    "GetWorkflowWorkflowExtractionJobsConnector",
    "GetWorkflowWorkflowExtractionJobsConnectorAzureImage",
    "GetWorkflowWorkflowExtractionJobsConnectorAzureText",
    "GetWorkflowWorkflowExtractionJobsConnectorModelImage",
    "GetWorkflowWorkflowExtractionJobsConnectorModelImageSpecification",
    "GetWorkflowWorkflowExtractionJobsConnectorModelText",
    "GetWorkflowWorkflowExtractionJobsConnectorModelTextSpecification",
    "GetWorkflowWorkflowExtractionJobsConnectorOpenAiImage",
    "GetWorkflowWorkflowIndexing",
    "GetWorkflowWorkflowIndexingJobs",
    "GetWorkflowWorkflowIndexingJobsConnector",
    "GetWorkflowWorkflowIngestion",
    "GetWorkflowWorkflowIngestionCollections",
    "GetWorkflowWorkflowIngestionIf",
    "GetWorkflowWorkflowOwner",
    "GetWorkflowWorkflowPreparation",
    "GetWorkflowWorkflowPreparationJobs",
    "GetWorkflowWorkflowPreparationJobsConnector",
    "GetWorkflowWorkflowPreparationJobsConnectorAzureDocument",
    "GetWorkflowWorkflowPreparationJobsConnectorDeepgram",
    "GetWorkflowWorkflowPreparationJobsConnectorDocument",
    "GetWorkflowWorkflowPreparationJobsConnectorEmail",
    "GetWorkflowWorkflowPreparationJobsConnectorModelDocument",
    "GetWorkflowWorkflowPreparationJobsConnectorModelDocumentSpecification",
    "GetWorkflowWorkflowPreparationSummarizations",
    "GetWorkflowWorkflowPreparationSummarizationsSpecification",
    "GetWorkflowWorkflowStorage",
    "GetWorkflowWorkflowStorageEmbeddings",
    "GitHubIssuesFeedPropertiesInput",
    "GitHubIssuesFeedPropertiesUpdateInput",
    "GoogleDriveFeedPropertiesInput",
    "GoogleDriveFeedPropertiesUpdateInput",
    "GoogleEmailFeedPropertiesInput",
    "GoogleEmailFeedPropertiesUpdateInput",
    "GoogleFeedPropertiesInput",
    "GoogleFeedPropertiesUpdateInput",
    "GraphQLClientError",
    "GraphQLClientGraphQLError",
    "GraphQLClientGraphQLMultiError",
    "GraphQLClientHttpError",
    "GraphQLClientInvalidResponseError",
    "GraphStrategyInput",
    "GraphStrategyTypes",
    "GraphStrategyUpdateInput",
    "GroqModelPropertiesInput",
    "GroqModelPropertiesUpdateInput",
    "GroqModels",
    "H3Filter",
    "H3IndexFilter",
    "H3ResolutionTypes",
    "INGEST_ENCODED_FILE_GQL",
    "INGEST_TEXT_GQL",
    "INGEST_URI_GQL",
    "IS_CONTENT_DONE_GQL",
    "IS_FEED_DONE_GQL",
    "ImageMetadataInput",
    "ImageProjectionTypes",
    "IndexingWorkflowJobInput",
    "IndexingWorkflowStageInput",
    "IngestEncodedFile",
    "IngestEncodedFileIngestEncodedFile",
    "IngestEncodedFileIngestEncodedFileCollections",
    "IngestText",
    "IngestTextIngestText",
    "IngestTextIngestTextCollections",
    "IngestUri",
    "IngestUriIngestUri",
    "IngestUriIngestUriCollections",
    "IngestionContentFilterInput",
    "IngestionWorkflowStageInput",
    "Int64RangeFilter",
    "IntegrationConnectorInput",
    "IntegrationConnectorUpdateInput",
    "IntegrationServiceTypes",
    "IsContentDone",
    "IsContentDoneIsContentDone",
    "IsFeedDone",
    "IsFeedDoneIsFeedDone",
    "IssueFeedPropertiesInput",
    "IssueFeedPropertiesUpdateInput",
    "IssueMetadataInput",
    "LOOKUP_CREDITS_GQL",
    "LOOKUP_USAGE_GQL",
    "LabelFacetInput",
    "LabelFacetTypes",
    "LabelFilter",
    "LabelInput",
    "LabelUpdateInput",
    "LanguageMetadataInput",
    "LinearFeedPropertiesInput",
    "LinearFeedPropertiesUpdateInput",
    "LinkStrategyInput",
    "LinkTypes",
    "LookupCredits",
    "LookupCreditsLookupCredits",
    "LookupUsage",
    "LookupUsageLookupUsage",
    "MailImportance",
    "MailPriority",
    "MailSensitivity",
    "MedicalConditionFacetInput",
    "MedicalConditionFacetTypes",
    "MedicalConditionFilter",
    "MedicalConditionInput",
    "MedicalConditionUpdateInput",
    "MedicalContraindicationFacetInput",
    "MedicalContraindicationFacetTypes",
    "MedicalContraindicationFilter",
    "MedicalContraindicationInput",
    "MedicalContraindicationUpdateInput",
    "MedicalDeviceFacetInput",
    "MedicalDeviceFacetTypes",
    "MedicalDeviceFilter",
    "MedicalDeviceInput",
    "MedicalDeviceUpdateInput",
    "MedicalDrugClassFacetInput",
    "MedicalDrugClassFacetTypes",
    "MedicalDrugClassFilter",
    "MedicalDrugClassInput",
    "MedicalDrugClassUpdateInput",
    "MedicalDrugFacetInput",
    "MedicalDrugFacetTypes",
    "MedicalDrugFilter",
    "MedicalDrugInput",
    "MedicalDrugUpdateInput",
    "MedicalGuidelineFacetInput",
    "MedicalGuidelineFacetTypes",
    "MedicalGuidelineFilter",
    "MedicalGuidelineInput",
    "MedicalGuidelineUpdateInput",
    "MedicalIndicationFacetInput",
    "MedicalIndicationFacetTypes",
    "MedicalIndicationFilter",
    "MedicalIndicationInput",
    "MedicalIndicationUpdateInput",
    "MedicalProcedureFacetInput",
    "MedicalProcedureFacetTypes",
    "MedicalProcedureFilter",
    "MedicalProcedureInput",
    "MedicalProcedureUpdateInput",
    "MedicalStudyFacetInput",
    "MedicalStudyFacetTypes",
    "MedicalStudyFilter",
    "MedicalStudyInput",
    "MedicalStudyUpdateInput",
    "MedicalTestFacetInput",
    "MedicalTestFacetTypes",
    "MedicalTestFilter",
    "MedicalTestInput",
    "MedicalTestUpdateInput",
    "MedicalTherapyFacetInput",
    "MedicalTherapyFacetTypes",
    "MedicalTherapyFilter",
    "MedicalTherapyInput",
    "MedicalTherapyUpdateInput",
    "MetadataFilter",
    "MetadataInput",
    "MetadataTypes",
    "MetadataUpdateInput",
    "MicrosoftEmailFeedPropertiesInput",
    "MicrosoftEmailFeedPropertiesUpdateInput",
    "MicrosoftTeamsChannelsInput",
    "MicrosoftTeamsFeedPropertiesInput",
    "MicrosoftTeamsFeedPropertiesUpdateInput",
    "MicrosoftTeamsTeamsInput",
    "MistralModelPropertiesInput",
    "MistralModelPropertiesUpdateInput",
    "MistralModels",
    "ModelDocumentPreparationInputProperties",
    "ModelImageExtractionPropertiesInput",
    "ModelServiceTypes",
    "ModelTextExtractionPropertiesInput",
    "NamedEntityReferenceInput",
    "NotionFeedPropertiesInput",
    "NotionFeedPropertiesUpdateInput",
    "NotionTypes",
    "ObservableTypes",
    "ObservationCriteriaInput",
    "ObservationInput",
    "ObservationOccurrenceInput",
    "ObservationReferenceFilter",
    "ObservationUpdateInput",
    "OccurrenceTypes",
    "OneDriveFeedPropertiesInput",
    "OneDriveFeedPropertiesUpdateInput",
    "OneDriveFoldersInput",
    "OpenAIImageExtractionPropertiesInput",
    "OpenAIModelPropertiesInput",
    "OpenAIModelPropertiesUpdateInput",
    "OpenAIModels",
    "OpenAIVisionDetailLevels",
    "OperationTypes",
    "OrderByTypes",
    "OrderDirectionTypes",
    "OrganizationFacetInput",
    "OrganizationFacetTypes",
    "OrganizationFilter",
    "OrganizationInput",
    "OrganizationUpdateInput",
    "OrientationTypes",
    "PROMPT_CONVERSATION_GQL",
    "PROMPT_SPECIFICATIONS_GQL",
    "PUBLISH_CONTENTS_GQL",
    "PUBLISH_CONVERSATION_GQL",
    "PUBLISH_TEXT_GQL",
    "PackageMetadataInput",
    "PersonFacetInput",
    "PersonFacetTypes",
    "PersonFilter",
    "PersonInput",
    "PersonUpdateInput",
    "PlaceFacetInput",
    "PlaceFacetTypes",
    "PlaceFilter",
    "PlaceInput",
    "PlaceUpdateInput",
    "PointCloudMetadataInput",
    "PointFilter",
    "PointInput",
    "PolicyTimeTypes",
    "PreparationWorkflowJobInput",
    "PreparationWorkflowStageInput",
    "ProductFacetInput",
    "ProductFacetTypes",
    "ProductFilter",
    "ProductInput",
    "ProductUpdateInput",
    "ProjectFilter",
    "ProjectInput",
    "ProjectQuotaInput",
    "ProjectUpdateInput",
    "PromptConversation",
    "PromptConversationPromptConversation",
    "PromptConversationPromptConversationConversation",
    "PromptConversationPromptConversationFacets",
    "PromptConversationPromptConversationFacetsObservable",
    "PromptConversationPromptConversationFacetsObservableObservable",
    "PromptConversationPromptConversationFacetsRange",
    "PromptConversationPromptConversationGraph",
    "PromptConversationPromptConversationGraphEdges",
    "PromptConversationPromptConversationGraphNodes",
    "PromptConversationPromptConversationMessage",
    "PromptConversationPromptConversationMessageCitations",
    "PromptConversationPromptConversationMessageCitationsContent",
    "PromptConversationPromptConversationMessageCitationsContentAudio",
    "PromptConversationPromptConversationMessageCitationsContentDocument",
    "PromptConversationPromptConversationMessageCitationsContentImage",
    "PromptConversationPromptConversationMessageCitationsContentVideo",
    "PromptSpecifications",
    "PromptSpecificationsPromptSpecifications",
    "PromptSpecificationsPromptSpecificationsMessages",
    "PromptSpecificationsPromptSpecificationsMessagesCitations",
    "PromptSpecificationsPromptSpecificationsMessagesCitationsContent",
    "PromptSpecificationsPromptSpecificationsMessagesCitationsContentAudio",
    "PromptSpecificationsPromptSpecificationsMessagesCitationsContentDocument",
    "PromptSpecificationsPromptSpecificationsMessagesCitationsContentImage",
    "PromptSpecificationsPromptSpecificationsMessagesCitationsContentVideo",
    "PromptSpecificationsPromptSpecificationsSpecification",
    "PromptStrategyInput",
    "PromptStrategyTypes",
    "PromptStrategyUpdateInput",
    "PublishContents",
    "PublishContentsPublishContents",
    "PublishContentsPublishContentsCollections",
    "PublishConversation",
    "PublishConversationPublishConversation",
    "PublishConversationPublishConversationCollections",
    "PublishText",
    "PublishTextPublishText",
    "PublishTextPublishTextCollections",
    "QUERY_ALERTS_GQL",
    "QUERY_CATEGORIES_GQL",
    "QUERY_COLLECTIONS_GQL",
    "QUERY_CONTENTS_FACETS_GQL",
    "QUERY_CONTENTS_GQL",
    "QUERY_CONTENTS_GRAPH_GQL",
    "QUERY_CONVERSATIONS_GQL",
    "QUERY_CREDITS_GQL",
    "QUERY_EVENTS_GQL",
    "QUERY_FEEDS_GQL",
    "QUERY_LABELS_GQL",
    "QUERY_MEDICAL_CONDITIONS_GQL",
    "QUERY_MEDICAL_CONTRAINDICATIONS_GQL",
    "QUERY_MEDICAL_DEVICES_GQL",
    "QUERY_MEDICAL_DRUGS_GQL",
    "QUERY_MEDICAL_DRUG_CLASSES_GQL",
    "QUERY_MEDICAL_GUIDELINES_GQL",
    "QUERY_MEDICAL_INDICATIONS_GQL",
    "QUERY_MEDICAL_PROCEDURES_GQL",
    "QUERY_MEDICAL_STUDIES_GQL",
    "QUERY_MEDICAL_TESTS_GQL",
    "QUERY_MEDICAL_THERAPIES_GQL",
    "QUERY_MICROSOFT_TEAMS_CHANNELS_GQL",
    "QUERY_MICROSOFT_TEAMS_TEAMS_GQL",
    "QUERY_ONE_DRIVE_FOLDERS_GQL",
    "QUERY_ORGANIZATIONS_GQL",
    "QUERY_PERSONS_GQL",
    "QUERY_PLACES_GQL",
    "QUERY_PRODUCTS_GQL",
    "QUERY_REPOS_GQL",
    "QUERY_SHARE_POINT_FOLDERS_GQL",
    "QUERY_SHARE_POINT_LIBRARIES_GQL",
    "QUERY_SOFTWARES_GQL",
    "QUERY_SPECIFICATIONS_GQL",
    "QUERY_USAGE_GQL",
    "QUERY_WORKFLOWS_GQL",
    "QueryAlerts",
    "QueryAlertsAlerts",
    "QueryAlertsAlertsResults",
    "QueryAlertsAlertsResultsFilter",
    "QueryAlertsAlertsResultsFilterAnd",
    "QueryAlertsAlertsResultsFilterAndCollections",
    "QueryAlertsAlertsResultsFilterAndFeeds",
    "QueryAlertsAlertsResultsFilterAndObservations",
    "QueryAlertsAlertsResultsFilterAndObservationsObservable",
    "QueryAlertsAlertsResultsFilterAndWorkflows",
    "QueryAlertsAlertsResultsFilterCollections",
    "QueryAlertsAlertsResultsFilterContents",
    "QueryAlertsAlertsResultsFilterCreationDateRange",
    "QueryAlertsAlertsResultsFilterDateRange",
    "QueryAlertsAlertsResultsFilterFeeds",
    "QueryAlertsAlertsResultsFilterObservations",
    "QueryAlertsAlertsResultsFilterObservationsObservable",
    "QueryAlertsAlertsResultsFilterOr",
    "QueryAlertsAlertsResultsFilterOrCollections",
    "QueryAlertsAlertsResultsFilterOrFeeds",
    "QueryAlertsAlertsResultsFilterOrObservations",
    "QueryAlertsAlertsResultsFilterOrObservationsObservable",
    "QueryAlertsAlertsResultsFilterOrWorkflows",
    "QueryAlertsAlertsResultsFilterWorkflows",
    "QueryAlertsAlertsResultsIntegration",
    "QueryAlertsAlertsResultsIntegrationSlack",
    "QueryAlertsAlertsResultsOwner",
    "QueryAlertsAlertsResultsPublishSpecification",
    "QueryAlertsAlertsResultsPublishing",
    "QueryAlertsAlertsResultsPublishingElevenLabs",
    "QueryAlertsAlertsResultsSummarySpecification",
    "QueryCategories",
    "QueryCategoriesCategories",
    "QueryCategoriesCategoriesResults",
    "QueryCollections",
    "QueryCollectionsCollections",
    "QueryCollectionsCollectionsResults",
    "QueryCollectionsCollectionsResultsContents",
    "QueryCollectionsCollectionsResultsOwner",
    "QueryContents",
    "QueryContentsContents",
    "QueryContentsContentsResults",
    "QueryContentsContentsResultsAddress",
    "QueryContentsContentsResultsAudio",
    "QueryContentsContentsResultsChildren",
    "QueryContentsContentsResultsCollections",
    "QueryContentsContentsResultsDocument",
    "QueryContentsContentsResultsEmail",
    "QueryContentsContentsResultsEmailBcc",
    "QueryContentsContentsResultsEmailCc",
    "QueryContentsContentsResultsEmailFrom",
    "QueryContentsContentsResultsEmailTo",
    "QueryContentsContentsResultsFeed",
    "QueryContentsContentsResultsImage",
    "QueryContentsContentsResultsIssue",
    "QueryContentsContentsResultsLanguage",
    "QueryContentsContentsResultsLinks",
    "QueryContentsContentsResultsLocation",
    "QueryContentsContentsResultsObservations",
    "QueryContentsContentsResultsObservationsObservable",
    "QueryContentsContentsResultsObservationsOccurrences",
    "QueryContentsContentsResultsObservationsOccurrencesBoundingBox",
    "QueryContentsContentsResultsObservationsRelated",
    "QueryContentsContentsResultsOwner",
    "QueryContentsContentsResultsPackage",
    "QueryContentsContentsResultsPages",
    "QueryContentsContentsResultsPagesChunks",
    "QueryContentsContentsResultsParent",
    "QueryContentsContentsResultsSegments",
    "QueryContentsContentsResultsVideo",
    "QueryContentsContentsResultsWorkflow",
    "QueryContentsFacets",
    "QueryContentsFacetsContents",
    "QueryContentsFacetsContentsFacets",
    "QueryContentsFacetsContentsFacetsObservable",
    "QueryContentsFacetsContentsFacetsObservableObservable",
    "QueryContentsFacetsContentsFacetsRange",
    "QueryContentsFacetsContentsResults",
    "QueryContentsFacetsContentsResultsAddress",
    "QueryContentsFacetsContentsResultsAudio",
    "QueryContentsFacetsContentsResultsChildren",
    "QueryContentsFacetsContentsResultsCollections",
    "QueryContentsFacetsContentsResultsDocument",
    "QueryContentsFacetsContentsResultsEmail",
    "QueryContentsFacetsContentsResultsEmailBcc",
    "QueryContentsFacetsContentsResultsEmailCc",
    "QueryContentsFacetsContentsResultsEmailFrom",
    "QueryContentsFacetsContentsResultsEmailTo",
    "QueryContentsFacetsContentsResultsFeed",
    "QueryContentsFacetsContentsResultsImage",
    "QueryContentsFacetsContentsResultsIssue",
    "QueryContentsFacetsContentsResultsLanguage",
    "QueryContentsFacetsContentsResultsLinks",
    "QueryContentsFacetsContentsResultsLocation",
    "QueryContentsFacetsContentsResultsObservations",
    "QueryContentsFacetsContentsResultsObservationsObservable",
    "QueryContentsFacetsContentsResultsObservationsOccurrences",
    "QueryContentsFacetsContentsResultsObservationsOccurrencesBoundingBox",
    "QueryContentsFacetsContentsResultsObservationsRelated",
    "QueryContentsFacetsContentsResultsOwner",
    "QueryContentsFacetsContentsResultsPackage",
    "QueryContentsFacetsContentsResultsPages",
    "QueryContentsFacetsContentsResultsPagesChunks",
    "QueryContentsFacetsContentsResultsParent",
    "QueryContentsFacetsContentsResultsSegments",
    "QueryContentsFacetsContentsResultsVideo",
    "QueryContentsFacetsContentsResultsWorkflow",
    "QueryContentsGraph",
    "QueryContentsGraphContents",
    "QueryContentsGraphContentsGraph",
    "QueryContentsGraphContentsGraphEdges",
    "QueryContentsGraphContentsGraphNodes",
    "QueryConversations",
    "QueryConversationsConversations",
    "QueryConversationsConversationsResults",
    "QueryConversationsConversationsResultsAugmentedFilter",
    "QueryConversationsConversationsResultsAugmentedFilterAnd",
    "QueryConversationsConversationsResultsAugmentedFilterAndCollections",
    "QueryConversationsConversationsResultsAugmentedFilterAndFeeds",
    "QueryConversationsConversationsResultsAugmentedFilterAndObservations",
    "QueryConversationsConversationsResultsAugmentedFilterAndObservationsObservable",
    "QueryConversationsConversationsResultsAugmentedFilterAndWorkflows",
    "QueryConversationsConversationsResultsAugmentedFilterCollections",
    "QueryConversationsConversationsResultsAugmentedFilterContents",
    "QueryConversationsConversationsResultsAugmentedFilterCreationDateRange",
    "QueryConversationsConversationsResultsAugmentedFilterDateRange",
    "QueryConversationsConversationsResultsAugmentedFilterFeeds",
    "QueryConversationsConversationsResultsAugmentedFilterObservations",
    "QueryConversationsConversationsResultsAugmentedFilterObservationsObservable",
    "QueryConversationsConversationsResultsAugmentedFilterOr",
    "QueryConversationsConversationsResultsAugmentedFilterOrCollections",
    "QueryConversationsConversationsResultsAugmentedFilterOrFeeds",
    "QueryConversationsConversationsResultsAugmentedFilterOrObservations",
    "QueryConversationsConversationsResultsAugmentedFilterOrObservationsObservable",
    "QueryConversationsConversationsResultsAugmentedFilterOrWorkflows",
    "QueryConversationsConversationsResultsAugmentedFilterWorkflows",
    "QueryConversationsConversationsResultsFilter",
    "QueryConversationsConversationsResultsFilterAnd",
    "QueryConversationsConversationsResultsFilterAndCollections",
    "QueryConversationsConversationsResultsFilterAndFeeds",
    "QueryConversationsConversationsResultsFilterAndObservations",
    "QueryConversationsConversationsResultsFilterAndObservationsObservable",
    "QueryConversationsConversationsResultsFilterAndWorkflows",
    "QueryConversationsConversationsResultsFilterCollections",
    "QueryConversationsConversationsResultsFilterContents",
    "QueryConversationsConversationsResultsFilterCreationDateRange",
    "QueryConversationsConversationsResultsFilterDateRange",
    "QueryConversationsConversationsResultsFilterFeeds",
    "QueryConversationsConversationsResultsFilterObservations",
    "QueryConversationsConversationsResultsFilterObservationsObservable",
    "QueryConversationsConversationsResultsFilterOr",
    "QueryConversationsConversationsResultsFilterOrCollections",
    "QueryConversationsConversationsResultsFilterOrFeeds",
    "QueryConversationsConversationsResultsFilterOrObservations",
    "QueryConversationsConversationsResultsFilterOrObservationsObservable",
    "QueryConversationsConversationsResultsFilterOrWorkflows",
    "QueryConversationsConversationsResultsFilterWorkflows",
    "QueryConversationsConversationsResultsMessages",
    "QueryConversationsConversationsResultsMessagesCitations",
    "QueryConversationsConversationsResultsMessagesCitationsContent",
    "QueryConversationsConversationsResultsMessagesCitationsContentAudio",
    "QueryConversationsConversationsResultsMessagesCitationsContentDocument",
    "QueryConversationsConversationsResultsMessagesCitationsContentImage",
    "QueryConversationsConversationsResultsMessagesCitationsContentVideo",
    "QueryConversationsConversationsResultsOwner",
    "QueryConversationsConversationsResultsSpecification",
    "QueryCredits",
    "QueryCreditsCredits",
    "QueryEvents",
    "QueryEventsEvents",
    "QueryEventsEventsResults",
    "QueryEventsEventsResultsAddress",
    "QueryFeeds",
    "QueryFeedsFeeds",
    "QueryFeedsFeedsResults",
    "QueryFeedsFeedsResultsDiscord",
    "QueryFeedsFeedsResultsEmail",
    "QueryFeedsFeedsResultsEmailGoogle",
    "QueryFeedsFeedsResultsEmailMicrosoft",
    "QueryFeedsFeedsResultsIssue",
    "QueryFeedsFeedsResultsIssueGithub",
    "QueryFeedsFeedsResultsIssueJira",
    "QueryFeedsFeedsResultsIssueLinear",
    "QueryFeedsFeedsResultsNotion",
    "QueryFeedsFeedsResultsOwner",
    "QueryFeedsFeedsResultsReddit",
    "QueryFeedsFeedsResultsRss",
    "QueryFeedsFeedsResultsSchedulePolicy",
    "QueryFeedsFeedsResultsSearch",
    "QueryFeedsFeedsResultsSite",
    "QueryFeedsFeedsResultsSiteAzureBlob",
    "QueryFeedsFeedsResultsSiteAzureFile",
    "QueryFeedsFeedsResultsSiteGoogle",
    "QueryFeedsFeedsResultsSiteGoogleDrive",
    "QueryFeedsFeedsResultsSiteOneDrive",
    "QueryFeedsFeedsResultsSiteS3",
    "QueryFeedsFeedsResultsSiteSharePoint",
    "QueryFeedsFeedsResultsSlack",
    "QueryFeedsFeedsResultsWeb",
    "QueryFeedsFeedsResultsWorkflow",
    "QueryFeedsFeedsResultsYoutube",
    "QueryLabels",
    "QueryLabelsLabels",
    "QueryLabelsLabelsResults",
    "QueryMedicalConditions",
    "QueryMedicalConditionsMedicalConditions",
    "QueryMedicalConditionsMedicalConditionsResults",
    "QueryMedicalContraindications",
    "QueryMedicalContraindicationsMedicalContraindications",
    "QueryMedicalContraindicationsMedicalContraindicationsResults",
    "QueryMedicalDevices",
    "QueryMedicalDevicesMedicalDevices",
    "QueryMedicalDevicesMedicalDevicesResults",
    "QueryMedicalDrugClasses",
    "QueryMedicalDrugClassesMedicalDrugClasses",
    "QueryMedicalDrugClassesMedicalDrugClassesResults",
    "QueryMedicalDrugs",
    "QueryMedicalDrugsMedicalDrugs",
    "QueryMedicalDrugsMedicalDrugsResults",
    "QueryMedicalGuidelines",
    "QueryMedicalGuidelinesMedicalGuidelines",
    "QueryMedicalGuidelinesMedicalGuidelinesResults",
    "QueryMedicalIndications",
    "QueryMedicalIndicationsMedicalIndications",
    "QueryMedicalIndicationsMedicalIndicationsResults",
    "QueryMedicalProcedures",
    "QueryMedicalProceduresMedicalProcedures",
    "QueryMedicalProceduresMedicalProceduresResults",
    "QueryMedicalStudies",
    "QueryMedicalStudiesMedicalStudies",
    "QueryMedicalStudiesMedicalStudiesResults",
    "QueryMedicalStudiesMedicalStudiesResultsAddress",
    "QueryMedicalTests",
    "QueryMedicalTestsMedicalTests",
    "QueryMedicalTestsMedicalTestsResults",
    "QueryMedicalTherapies",
    "QueryMedicalTherapiesMedicalTherapies",
    "QueryMedicalTherapiesMedicalTherapiesResults",
    "QueryMicrosoftTeamsChannels",
    "QueryMicrosoftTeamsChannelsMicrosoftTeamsChannels",
    "QueryMicrosoftTeamsChannelsMicrosoftTeamsChannelsResults",
    "QueryMicrosoftTeamsTeams",
    "QueryMicrosoftTeamsTeamsMicrosoftTeamsTeams",
    "QueryMicrosoftTeamsTeamsMicrosoftTeamsTeamsResults",
    "QueryOneDriveFolders",
    "QueryOneDriveFoldersOneDriveFolders",
    "QueryOneDriveFoldersOneDriveFoldersResults",
    "QueryOrganizations",
    "QueryOrganizationsOrganizations",
    "QueryOrganizationsOrganizationsResults",
    "QueryOrganizationsOrganizationsResultsAddress",
    "QueryPersons",
    "QueryPersonsPersons",
    "QueryPersonsPersonsResults",
    "QueryPersonsPersonsResultsAddress",
    "QueryPlaces",
    "QueryPlacesPlaces",
    "QueryPlacesPlacesResults",
    "QueryPlacesPlacesResultsAddress",
    "QueryProducts",
    "QueryProductsProducts",
    "QueryProductsProductsResults",
    "QueryProductsProductsResultsAddress",
    "QueryRepos",
    "QueryReposRepos",
    "QueryReposReposResults",
    "QuerySharePointFolders",
    "QuerySharePointFoldersSharePointFolders",
    "QuerySharePointFoldersSharePointFoldersResults",
    "QuerySharePointLibraries",
    "QuerySharePointLibrariesSharePointLibraries",
    "QuerySharePointLibrariesSharePointLibrariesResults",
    "QuerySoftwares",
    "QuerySoftwaresSoftwares",
    "QuerySoftwaresSoftwaresResults",
    "QuerySpecifications",
    "QuerySpecificationsSpecifications",
    "QuerySpecificationsSpecificationsResults",
    "QuerySpecificationsSpecificationsResultsAnthropic",
    "QuerySpecificationsSpecificationsResultsAzureOpenAi",
    "QuerySpecificationsSpecificationsResultsCohere",
    "QuerySpecificationsSpecificationsResultsDeepseek",
    "QuerySpecificationsSpecificationsResultsGraphStrategy",
    "QuerySpecificationsSpecificationsResultsGroq",
    "QuerySpecificationsSpecificationsResultsMistral",
    "QuerySpecificationsSpecificationsResultsOpenAi",
    "QuerySpecificationsSpecificationsResultsOwner",
    "QuerySpecificationsSpecificationsResultsPromptStrategy",
    "QuerySpecificationsSpecificationsResultsReplicate",
    "QuerySpecificationsSpecificationsResultsRerankingStrategy",
    "QuerySpecificationsSpecificationsResultsRetrievalStrategy",
    "QuerySpecificationsSpecificationsResultsRevisionStrategy",
    "QuerySpecificationsSpecificationsResultsStrategy",
    "QuerySpecificationsSpecificationsResultsTools",
    "QueryUsage",
    "QueryUsageUsage",
    "QueryWorkflows",
    "QueryWorkflowsWorkflows",
    "QueryWorkflowsWorkflowsResults",
    "QueryWorkflowsWorkflowsResultsActions",
    "QueryWorkflowsWorkflowsResultsActionsConnector",
    "QueryWorkflowsWorkflowsResultsActionsConnectorSlack",
    "QueryWorkflowsWorkflowsResultsEnrichment",
    "QueryWorkflowsWorkflowsResultsEnrichmentJobs",
    "QueryWorkflowsWorkflowsResultsEnrichmentJobsConnector",
    "QueryWorkflowsWorkflowsResultsEnrichmentJobsConnectorFhir",
    "QueryWorkflowsWorkflowsResultsEnrichmentLink",
    "QueryWorkflowsWorkflowsResultsExtraction",
    "QueryWorkflowsWorkflowsResultsExtractionJobs",
    "QueryWorkflowsWorkflowsResultsExtractionJobsConnector",
    "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorAzureImage",
    "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorAzureText",
    "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelImage",
    "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelImageSpecification",
    "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelText",
    "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelTextSpecification",
    "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorOpenAiImage",
    "QueryWorkflowsWorkflowsResultsIndexing",
    "QueryWorkflowsWorkflowsResultsIndexingJobs",
    "QueryWorkflowsWorkflowsResultsIndexingJobsConnector",
    "QueryWorkflowsWorkflowsResultsIngestion",
    "QueryWorkflowsWorkflowsResultsIngestionCollections",
    "QueryWorkflowsWorkflowsResultsIngestionIf",
    "QueryWorkflowsWorkflowsResultsOwner",
    "QueryWorkflowsWorkflowsResultsPreparation",
    "QueryWorkflowsWorkflowsResultsPreparationJobs",
    "QueryWorkflowsWorkflowsResultsPreparationJobsConnector",
    "QueryWorkflowsWorkflowsResultsPreparationJobsConnectorAzureDocument",
    "QueryWorkflowsWorkflowsResultsPreparationJobsConnectorDeepgram",
    "QueryWorkflowsWorkflowsResultsPreparationJobsConnectorDocument",
    "QueryWorkflowsWorkflowsResultsPreparationJobsConnectorEmail",
    "QueryWorkflowsWorkflowsResultsPreparationJobsConnectorModelDocument",
    "QueryWorkflowsWorkflowsResultsPreparationJobsConnectorModelDocumentSpecification",
    "QueryWorkflowsWorkflowsResultsPreparationSummarizations",
    "QueryWorkflowsWorkflowsResultsPreparationSummarizationsSpecification",
    "QueryWorkflowsWorkflowsResultsStorage",
    "QueryWorkflowsWorkflowsResultsStorageEmbeddings",
    "REMOVE_CONTENTS_FROM_COLLECTION_GQL",
    "RSSFeedPropertiesInput",
    "RSSFeedPropertiesUpdateInput",
    "RedditFeedPropertiesInput",
    "RedditFeedPropertiesUpdateInput",
    "RemoveContentsFromCollection",
    "RemoveContentsFromCollectionRemoveContentsFromCollection",
    "RemoveContentsFromCollectionRemoveContentsFromCollectionContents",
    "RenditionTypes",
    "ReplicateModelPropertiesInput",
    "ReplicateModelPropertiesUpdateInput",
    "ReplicateModels",
    "RepoFacetInput",
    "RepoFacetTypes",
    "RepoFilter",
    "RepoInput",
    "RepoUpdateInput",
    "RerankingModelServiceTypes",
    "RerankingStrategyInput",
    "RerankingStrategyUpdateInput",
    "ResourceConnectorTypes",
    "RetrievalStrategyInput",
    "RetrievalStrategyTypes",
    "RetrievalStrategyUpdateInput",
    "RevisionStrategyInput",
    "RevisionStrategyTypes",
    "RevisionStrategyUpdateInput",
    "SUGGEST_CONVERSATION_GQL",
    "SUMMARIZE_CONTENTS_GQL",
    "SearchFeedPropertiesInput",
    "SearchFeedPropertiesUpdateInput",
    "SearchQueryTypes",
    "SearchServiceTypes",
    "SearchTypes",
    "ShapeMetadataInput",
    "SharePointAuthenticationTypes",
    "SharePointFeedPropertiesInput",
    "SharePointFeedPropertiesUpdateInput",
    "SharePointFoldersInput",
    "SharePointLibrariesInput",
    "SiteFeedPropertiesInput",
    "SiteFeedPropertiesUpdateInput",
    "SiteTypes",
    "SlackChannelsInput",
    "SlackFeedPropertiesInput",
    "SlackFeedPropertiesUpdateInput",
    "SlackIntegrationPropertiesInput",
    "SoftwareFacetInput",
    "SoftwareFacetTypes",
    "SoftwareFilter",
    "SoftwareInput",
    "SoftwareUpdateInput",
    "SpecificationFilter",
    "SpecificationInput",
    "SpecificationTypes",
    "SpecificationUpdateInput",
    "StorageWorkflowStageInput",
    "SuggestConversation",
    "SuggestConversationSuggestConversation",
    "SummarizationStrategyInput",
    "SummarizationTypes",
    "SummarizeContents",
    "SummarizeContentsSummarizeContents",
    "SummarizeContentsSummarizeContentsContent",
    "SummarizeContentsSummarizeContentsItems",
    "SummarizeContentsSummarizeContentsSpecification",
    "TextRoles",
    "TextTypes",
    "TimeIntervalTypes",
    "TimedPolicyRecurrenceTypes",
    "ToolDefinitionInput",
    "ToolDefinitionUpdateInput",
    "UPDATE_ALERT_GQL",
    "UPDATE_CATEGORY_GQL",
    "UPDATE_COLLECTION_GQL",
    "UPDATE_CONTENT_GQL",
    "UPDATE_CONVERSATION_GQL",
    "UPDATE_EVENT_GQL",
    "UPDATE_FEED_GQL",
    "UPDATE_LABEL_GQL",
    "UPDATE_MEDICAL_CONDITION_GQL",
    "UPDATE_MEDICAL_CONTRAINDICATION_GQL",
    "UPDATE_MEDICAL_DEVICE_GQL",
    "UPDATE_MEDICAL_DRUG_CLASS_GQL",
    "UPDATE_MEDICAL_DRUG_GQL",
    "UPDATE_MEDICAL_GUIDELINE_GQL",
    "UPDATE_MEDICAL_INDICATION_GQL",
    "UPDATE_MEDICAL_PROCEDURE_GQL",
    "UPDATE_MEDICAL_STUDY_GQL",
    "UPDATE_MEDICAL_TEST_GQL",
    "UPDATE_MEDICAL_THERAPY_GQL",
    "UPDATE_OBSERVATION_GQL",
    "UPDATE_ORGANIZATION_GQL",
    "UPDATE_PERSON_GQL",
    "UPDATE_PLACE_GQL",
    "UPDATE_PRODUCT_GQL",
    "UPDATE_PROJECT_GQL",
    "UPDATE_REPO_GQL",
    "UPDATE_SOFTWARE_GQL",
    "UPDATE_SPECIFICATION_GQL",
    "UPDATE_WORKFLOW_GQL",
    "UnitTypes",
    "UpdateAlert",
    "UpdateAlertUpdateAlert",
    "UpdateCategory",
    "UpdateCategoryUpdateCategory",
    "UpdateCollection",
    "UpdateCollectionUpdateCollection",
    "UpdateContent",
    "UpdateContentUpdateContent",
    "UpdateContentUpdateContentCollections",
    "UpdateConversation",
    "UpdateConversationUpdateConversation",
    "UpdateEvent",
    "UpdateEventUpdateEvent",
    "UpdateFeed",
    "UpdateFeedUpdateFeed",
    "UpdateLabel",
    "UpdateLabelUpdateLabel",
    "UpdateMedicalCondition",
    "UpdateMedicalConditionUpdateMedicalCondition",
    "UpdateMedicalContraindication",
    "UpdateMedicalContraindicationUpdateMedicalContraindication",
    "UpdateMedicalDevice",
    "UpdateMedicalDeviceUpdateMedicalDevice",
    "UpdateMedicalDrug",
    "UpdateMedicalDrugClass",
    "UpdateMedicalDrugClassUpdateMedicalDrugClass",
    "UpdateMedicalDrugUpdateMedicalDrug",
    "UpdateMedicalGuideline",
    "UpdateMedicalGuidelineUpdateMedicalGuideline",
    "UpdateMedicalIndication",
    "UpdateMedicalIndicationUpdateMedicalIndication",
    "UpdateMedicalProcedure",
    "UpdateMedicalProcedureUpdateMedicalProcedure",
    "UpdateMedicalStudy",
    "UpdateMedicalStudyUpdateMedicalStudy",
    "UpdateMedicalTest",
    "UpdateMedicalTestUpdateMedicalTest",
    "UpdateMedicalTherapy",
    "UpdateMedicalTherapyUpdateMedicalTherapy",
    "UpdateObservation",
    "UpdateObservationUpdateObservation",
    "UpdateOrganization",
    "UpdateOrganizationUpdateOrganization",
    "UpdatePerson",
    "UpdatePersonUpdatePerson",
    "UpdatePlace",
    "UpdatePlaceUpdatePlace",
    "UpdateProduct",
    "UpdateProductUpdateProduct",
    "UpdateProject",
    "UpdateProjectUpdateProject",
    "UpdateRepo",
    "UpdateRepoUpdateRepo",
    "UpdateSoftware",
    "UpdateSoftwareUpdateSoftware",
    "UpdateSpecification",
    "UpdateSpecificationUpdateSpecification",
    "UpdateWorkflow",
    "UpdateWorkflowUpdateWorkflow",
    "UpdateWorkflowUpdateWorkflowActions",
    "UpdateWorkflowUpdateWorkflowActionsConnector",
    "UpdateWorkflowUpdateWorkflowActionsConnectorSlack",
    "UpdateWorkflowUpdateWorkflowEnrichment",
    "UpdateWorkflowUpdateWorkflowEnrichmentJobs",
    "UpdateWorkflowUpdateWorkflowEnrichmentJobsConnector",
    "UpdateWorkflowUpdateWorkflowEnrichmentJobsConnectorFhir",
    "UpdateWorkflowUpdateWorkflowEnrichmentLink",
    "UpdateWorkflowUpdateWorkflowExtraction",
    "UpdateWorkflowUpdateWorkflowExtractionJobs",
    "UpdateWorkflowUpdateWorkflowExtractionJobsConnector",
    "UpdateWorkflowUpdateWorkflowExtractionJobsConnectorAzureImage",
    "UpdateWorkflowUpdateWorkflowExtractionJobsConnectorAzureText",
    "UpdateWorkflowUpdateWorkflowExtractionJobsConnectorModelImage",
    "UpdateWorkflowUpdateWorkflowExtractionJobsConnectorModelImageSpecification",
    "UpdateWorkflowUpdateWorkflowExtractionJobsConnectorModelText",
    "UpdateWorkflowUpdateWorkflowExtractionJobsConnectorModelTextSpecification",
    "UpdateWorkflowUpdateWorkflowExtractionJobsConnectorOpenAiImage",
    "UpdateWorkflowUpdateWorkflowIndexing",
    "UpdateWorkflowUpdateWorkflowIndexingJobs",
    "UpdateWorkflowUpdateWorkflowIndexingJobsConnector",
    "UpdateWorkflowUpdateWorkflowIngestion",
    "UpdateWorkflowUpdateWorkflowIngestionCollections",
    "UpdateWorkflowUpdateWorkflowIngestionIf",
    "UpdateWorkflowUpdateWorkflowPreparation",
    "UpdateWorkflowUpdateWorkflowPreparationJobs",
    "UpdateWorkflowUpdateWorkflowPreparationJobsConnector",
    "UpdateWorkflowUpdateWorkflowPreparationJobsConnectorAzureDocument",
    "UpdateWorkflowUpdateWorkflowPreparationJobsConnectorDeepgram",
    "UpdateWorkflowUpdateWorkflowPreparationJobsConnectorDocument",
    "UpdateWorkflowUpdateWorkflowPreparationJobsConnectorEmail",
    "UpdateWorkflowUpdateWorkflowPreparationJobsConnectorModelDocument",
    "UpdateWorkflowUpdateWorkflowPreparationJobsConnectorModelDocumentSpecification",
    "UpdateWorkflowUpdateWorkflowPreparationSummarizations",
    "UpdateWorkflowUpdateWorkflowPreparationSummarizationsSpecification",
    "UpdateWorkflowUpdateWorkflowStorage",
    "UpdateWorkflowUpdateWorkflowStorageEmbeddings",
    "Upload",
    "VideoMetadataInput",
    "WebFeedPropertiesInput",
    "WebFeedPropertiesUpdateInput",
    "WorkflowActionInput",
    "WorkflowFilter",
    "WorkflowInput",
    "WorkflowUpdateInput",
    "YouTubeFeedPropertiesInput",
    "YouTubeFeedPropertiesUpdateInput",
    "YouTubeTypes",
]
